-- --------------------------------------------------------------------------
--
-- Create views (useful for backward compatibility or exploitation process)
--
--  project : SIH-Adagio :: Core Server
--  version : 4.1.22.2 for ${pom.env}
--      env : ${pom.env} - ${pom.profil}
--     date : ${pom.date.fr}
--
--  Copyright Ifremer 2009
-- 
-- 01/02/2009 BL  Creation
-- 31/01/2011 BL Ajout de la vue matérialisée DENORMALIZED_LOCATION_DCF (demande C.Merrien de 12/2010)
-- 05/04/2011 BL [modèle v3.1.1] Ajout de la vue HIS_FLUX, à partir de la table PROCESSING_HISTORY
-- 13/04/2011 BL Creation des vues GROUP_METIER_xx,
--               pour compatibilité avec la version 3.1.1 utilisée par les JAR de Recopesca-console
-- 09/08/2011 BL Ajout de la vue matérialisée DENORMALIZED_LOCATION_LAND (besoin Presto : produit P07)
-- 28/09/2011 BL Ajout des vues de compatibilite sur TRANSCRIBING_xxx
-- 04/10/2011 BL Mise … jour de DENORMALIZED_LOCATION_LAND, pour ajouter les facades, oc‚ans, supra-oc‚ans
-- 01/02/2012 NR Ajout de la vue DENORMALIZED_TAXON_GROUP_ASFIS (demande C.Merrien de 09/2011)
-- 20/04/2012 EB - Ajout de la vue FISHING_TRIP_PUBLIC permettant de securiser l'accŠs aux mar‚e VMS
--               - Ajout de la vue VESSEL_POSITION_COMPLETE, permettant d'acc‚der … l'ensemble des positions
--               (publiques et priv‚es)
-- 09/10/2013 EM Ajout vue DENORMALIZED_LOC_SCIENT_CRUIS (Mantis 17341)
-- 10/10/2013 EM Vue métier DENORMALIZED_WEIGHT_LENGTH_C pour les RTP (Mantis 17885)
-- 12/11/2013 EM Correction vue DENORMALIZED_LOC_SCIENT_CRUIS (Mantis 17341)
-- 17/02/2014 EB Vue métier DENORMALIZED_METIER_DCR               
-- 17/03/2014 EB Vue métier DENORMALIZED_SPATIAL_ITEM   
-- 21/10/2014 EM Modifications vue métier DENORMALIZED_WEIGHT_LENGTH_C (Mantis 21531: [Table de référence] vue des relation taille-poids)
-- 22/11/2014 EB Vue métier DENORMALIZED_LOC_MARITIME (mantis #21914) 
-- 22/10/2014 EB Vue métier DENORMALIZED_LOC_STAT (mantis #121632)  
-- 08/01/2015 EB Vue métier DENORMALIZED_GEAR_FAO (mantis #20855)
-- 26/01/2015 BL Add missing view AGE_READER_QUALIFICATIONS2PEOP (mantis #23785)
-- 09/04/2015 EB Add view DENORMALIZED_PROGRAM2PERSON
-- 08/07/2015 NR Ajout de la vue DENORMALIZED_OBSDEB_SYNC_OBS (demande P.Lespagnol de 07/2015)
-- 10/03/2016 EM Correction vue DENORMALIZED_PMFM (Mantis 26484)
-- 10/03/2016 EM Correction vue DENORMALIZED_QUALITATIVE_VALUE(Mantis 26484)
-- 10/03/2016 EM Correction vue DENORMALIZED_PARAMETER (Mantis 26484)
-- 23/03/2016 EM Added EMAIL in view DENORMALIZED_PROGRAM2PERSON (Mantis 29616)
-- 22/11/2017 NR Ajout des vues DENORMALIZED_PSION_* (Mantis 38857)
-- --------------------------------------------------------------------------
-- --------------------------------------------------------------------------
-- IMPORTANT NOTE : Execute the sql file after connect as SIH2_ADAGIO_DBA
-- --------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- Vue         : DENORMALIZED_LOCATION_DCF
-- Description : dénormalisation des zones en mer, suivant le transcodage DCF
-- 31/01/2011  BL Creation
--------------------------------------------------------------------------------
-- ID         	: identifiant interne de la zone en mer (LOCATION.ID)
-- LABEL        : mnémonique de la zone en mer (LOCATION.LABEL)
-- NAME         : libellé de la zone en mer (LOCATION.NAME)
-- LEVEL1_LABEL : mnémonique du lieu parent de niveau 1 DCF
-- LEVEL1_NAME  : libellé du lieu parent de niveau 1 DCF
-- LEVEL2_LABEL : mnémonique du lieu parent de niveau 2 DCF
-- LEVEL2_NAME  : libellé du lieu parent de niveau 2 DCF
-- LEVEL3_LABEL : mnémonique du lieu parent de niveau 3 DCF
-- LEVEL3_NAME  : libellé du lieu parent de niveau 3 DCF
-- LEVEL4_LABEL : mnémonique du lieu parent de niveau 4 DCF
-- LEVEL4_NAME  : libellé du lieu parent de niveau 4 DCF
-- LEVEL5_LABEL : mnémonique du lieu parent de niveau 5 DCF
-- LEVEL5_NAME  : libellé du lieu parent de niveau 5 DCF
--------------------------------------------------------------------------------
--DROP MATERIALIZED VIEW DENORMALIZED_LOCATION_DCF;
CREATE MATERIALIZED VIEW DENORMALIZED_LOCATION_DCF
TABLESPACE SIH2_ADAGIO_REF_DATA
NOCACHE
NOLOGGING
NOPARALLEL
BUILD IMMEDIATE
REFRESH ON DEMAND
AS
with DCF_LOCATION as 
  (
    select
      L.ID as ID,
      TL.EXTERNAL_CODE as LABEL,
      L.NAME as NAME, 
      to_number(substr(TLL.EXTERNAL_CODE,2/*skip caracter 'L'*/, 1), '99') as DCF_LEVEL
    from
      TRANSCRIBING_LOCATION_LEVEL TLL,
      TRANSCRIBING_LOCATION TL,
      LOCATION L
    where 1=1
      -- Selection des niveaux de lieux correspondant
      -- au système 'DCF' :
      and TLL.TRANSCRIBING_SYSTEM_FK= 10 -- =DCF
      and TLL.TRANSCRIBING_SIDE_FK in (1,3) -- out et in/out
      -- Sélection des lieux appartenant à ces niveaux 'L1' 
      and L.LOCATION_LEVEL_FK = TLL.LOCATION_LEVEL_FK
      and TL.LOCATION_FK = L.ID
      and TL.TRANSCRIBING_SYSTEM_FK=10 -- =DCF
      and TL.TRANSCRIBING_SIDE_FK in (1,3) -- out et in/out
  ),
LOCATION_HIERARCHY_ONE_PARENT as 
  (
    select distinct
      LH.CHILD_LOCATION_FK,
      FIRST_VALUE(LH.PARENT_LOCATION_FK) 
        OVER(
          PARTITION BY LH.CHILD_LOCATION_FK, L_PARENT.location_level_fk
          ORDER BY LH.CHILD_SURFACE_RATIO DESC
          ROWS UNBOUNDED PRECEDING
        )
      as PARENT_LOCATION_FK
    from     
      LOCATION_HIERARCHY LH,
      LOCATION L_PARENT
    where 1=1
      and L_PARENT.ID = LH.PARENT_LOCATION_FK
  )
select
  L_CHILD.ID,
  L_CHILD.LABEL,
  L_CHILD.NAME,
  L_CHILD.LOCATION_LEVEL_FK,
  LL.NAME as LOCATION_LEVEL_NAME,
  max(decode(DCF_PARENT.DCF_LEVEL, 1, DCF_PARENT.LABEL, NULL)) as LEVEL1_LABEL,
  max(decode(DCF_PARENT.DCF_LEVEL, 1, DCF_PARENT.NAME, NULL)) as LEVEL1_NAME,
  max(decode(DCF_PARENT.DCF_LEVEL, 2, DCF_PARENT.LABEL, NULL)) as LEVEL2_LABEL,
  max(decode(DCF_PARENT.DCF_LEVEL, 2, DCF_PARENT.NAME, NULL)) as LEVEL2_NAME,
  max(decode(DCF_PARENT.DCF_LEVEL, 3, DCF_PARENT.LABEL, NULL)) as LEVEL3_LABEL,
  max(decode(DCF_PARENT.DCF_LEVEL, 3, DCF_PARENT.NAME, NULL)) as LEVEL3_NAME,
  max(decode(DCF_PARENT.DCF_LEVEL, 4, DCF_PARENT.LABEL, NULL)) as LEVEL4_LABEL,
  max(decode(DCF_PARENT.DCF_LEVEL, 4, DCF_PARENT.NAME, NULL)) as LEVEL4_NAME,
  max(decode(DCF_PARENT.DCF_LEVEL, 5, DCF_PARENT.LABEL, NULL)) as LEVEL5_LABEL,
  max(decode(DCF_PARENT.DCF_LEVEL, 5, DCF_PARENT.NAME, NULL)) as LEVEL5_NAME
from
  LOCATION_HIERARCHY_ONE_PARENT LH,
  LOCATION L_CHILD, 
  DCF_LOCATION DCF_PARENT,
  LOCATION_LEVEL LL
where 1=1
  and LH.CHILD_LOCATION_FK = L_CHILD.ID
  and LH.PARENT_LOCATION_FK = DCF_PARENT.ID
  and L_CHILD.LOCATION_LEVEL_FK = LL.ID
  -- ask for a special location
  --and L_CHILD.ID = ?
group by 
  L_CHILD.ID, L_CHILD.LABEL, L_CHILD.NAME, L_CHILD.LOCATION_LEVEL_FK, LL.NAME
order by
  L_CHILD.LOCATION_LEVEL_FK, L_CHILD.LABEL;
/

--------------------------------------------------------------------------------
-- Vue         : DENORMALIZED_LOCATION_LAND
-- Description : denormalisation des zones en terrestre (port/qim/region/pays)
-- 09/08/2011  BL Creation (besoin Presto : produit P07 "SeaMap activity")
--------------------------------------------------------------------------------
-- ID         	: identifiant interne de la zone en mer (LOCATION.ID)
-- LABEL        : mnemonique de la zone en mer (LOCATION.LABEL)
-- NAME         : libelle de la zone en mer (LOCATION.NAME)
-- SALE_PLACE_LABEL : mnemonique du lieu parent criee
-- SALE_PLACE_NAME  : libelle du lieu parent criee
-- PORT_LABEL : mnemonique du lieu parent port
-- PORT_NAME  : libelle du lieu parent port
-- REGISTRATION_LABEL : mnemonique du lieu parent QIM
-- REGISTRATION_NAME  : libelle du lieu parent QIM
-- DISTRICT_LABEL : mnemonique du lieu parent Region
-- DISTRICT_NAME  : libelle du lieu parent Region
-- COUNTRY_LABEL : mnemonique du lieu parent Pays
-- COUNTRY_NAME  : libelle du lieu parent Pays
-- SEA_SIDE_LABEL : mnemonique de la facade
-- SEA_SIDE_NAME  : libelle de la facade
-- OCEAN_LABEL : mnemonique de l'ocean
-- OCEAN_NAME  : libelle de l'ocean
-- SUPRAOCEAN_LABEL : mnemonique du supra ocean
-- SUPRAOCEAN_NAME  : libelle du supra ocean
--------------------------------------------------------------------------------
DROP MATERIALIZED VIEW DENORMALIZED_LOCATION_LAND;
CREATE MATERIALIZED VIEW DENORMALIZED_LOCATION_LAND
TABLESPACE SIH2_ADAGIO_REF_DATA
NOCACHE
NOLOGGING
NOPARALLEL
BUILD IMMEDIATE
REFRESH ON DEMAND
AS
with LOCATION_HIERARCHY_ONE_PARENT as 
  (
    select distinct
      LH.CHILD_LOCATION_FK,
      FIRST_VALUE(LH.PARENT_LOCATION_FK) 
        OVER(
          PARTITION BY LH.CHILD_LOCATION_FK, L_PARENT.location_level_fk
          ORDER BY LH.CHILD_SURFACE_RATIO DESC
          ROWS UNBOUNDED PRECEDING
        )
      as PARENT_LOCATION_FK
    from     
      LOCATION_HIERARCHY LH,
      LOCATION L_PARENT
    where 1=1
      and L_PARENT.ID = LH.PARENT_LOCATION_FK
      and L_PARENT.LOCATION_CLASSIFICATION_FK=1/*zones terrestre*/
  ),
  GROUPING_LOCATION as (
    select 
      l.id as LOCATION_FK,
      g.label as LABEL,
      g.name as NAME,
      gl.name as GROUPING_LEVEL_NAME
    from 
      grouping_level gl,
      grouping g, 
      grouping_item_hierarchy gih,
      location_hierarchy lh,
      location l
    where 1=1
      and gl.grouping_classification_fk = 1
      and g.grouping_level_fk = gl.id
      and g.id = gih.grouping_fk
      and lh.parent_location_fk = gih.object_id
      and l.id = lh.child_location_fk
  )
select
  L_CHILD.ID,
  L_CHILD.LABEL,
  L_CHILD.NAME,
  L_CHILD.LOCATION_LEVEL_FK,
  LL.NAME as LOCATION_LEVEL_NAME,
  max(decode(LAND_PARENT.LOCATION_LEVEL_FK, 7,  LAND_PARENT.LABEL, NULL)) as SALE_PLACE_LABEL,
  max(decode(LAND_PARENT.LOCATION_LEVEL_FK, 7,  LAND_PARENT.NAME, NULL))  as SALE_PLACE_NAME,
  max(decode(LAND_PARENT.LOCATION_LEVEL_FK, 6,  LAND_PARENT.LABEL, NULL)) as PORT_LABEL,
  max(decode(LAND_PARENT.LOCATION_LEVEL_FK, 6,  LAND_PARENT.NAME, NULL))  as PORT_NAME,
  max(decode(LAND_PARENT.LOCATION_LEVEL_FK, 13, LAND_PARENT.LABEL, NULL)) as REGISTRATION_LABEL,
  max(decode(LAND_PARENT.LOCATION_LEVEL_FK, 13, LAND_PARENT.NAME, NULL))  as REGISTRATION_NAME,
  max(decode(LAND_PARENT.LOCATION_LEVEL_FK, 31, LAND_PARENT.LABEL, NULL)) as DISTRICT_LABEL,
  max(decode(LAND_PARENT.LOCATION_LEVEL_FK, 31, LAND_PARENT.NAME, NULL))  as DISTRICT_NAME,
  max(decode(LAND_PARENT.LOCATION_LEVEL_FK, 21, LAND_PARENT.LABEL, NULL)) as COUNTRY_LABEL,
  max(decode(LAND_PARENT.LOCATION_LEVEL_FK, 21, LAND_PARENT.NAME, NULL))  as COUNTRY_NAME,
  max(decode(GL.GROUPING_LEVEL_NAME, '51', GL.LABEL, NULL))               as SEA_SIDE_LABEL,
  max(decode(GL.GROUPING_LEVEL_NAME, '51', GL.NAME, NULL))                as SEA_SIDE_NAME, 
  max(decode(GL.GROUPING_LEVEL_NAME, '50', GL.LABEL, NULL))               as OCEAN_LABEL,
  max(decode(GL.GROUPING_LEVEL_NAME, '50', GL.NAME, NULL))                as OCEAN_NAME, 
  max(decode(GL.GROUPING_LEVEL_NAME, '49', GL.LABEL, NULL))               as SUPRAOCEAN_LABEL,
  max(decode(GL.GROUPING_LEVEL_NAME, '49', GL.NAME, NULL))                as SUPRAOCEAN_NAME  
from
  LOCATION_HIERARCHY_ONE_PARENT LH,
  LOCATION LAND_PARENT,
  LOCATION_LEVEL LL,
  LOCATION L_CHILD
    left outer join GROUPING_LOCATION GL
      on L_CHILD.ID = GL.LOCATION_FK
where 1=1
  and LH.CHILD_LOCATION_FK = L_CHILD.ID
  and LH.PARENT_LOCATION_FK = LAND_PARENT.ID
  and L_CHILD.LOCATION_LEVEL_FK = LL.ID
  -- uniquement les zones terrestre
  and L_CHILD.LOCATION_CLASSIFICATION_FK=1 /*=zones terrestre*/
  and LAND_PARENT.LOCATION_CLASSIFICATION_FK=1 /*=zones terrestre*/
  -- ask for a special location
  --and L_CHILD.ID = ?
group by 
  L_CHILD.ID, L_CHILD.LABEL, L_CHILD.NAME, L_CHILD.LOCATION_LEVEL_FK, LL.NAME
order by
  L_CHILD.LOCATION_LEVEL_FK, L_CHILD.LABEL;
/

--------------------------------------------------------------------------------
-- Vue         : HIS_FLUX
-- Description : maintient des fonctionnalités de l'ancienne table HIS_FLUX
-- 05/04/2011  BL Creation
--------------------------------------------------------------------------------
-- ID         	: identifiant interne
-- TYPE_FLUX    : recopié de PROCESSING_HISTORY.PROCESSING_TYPE_FK
-- NOM_FLUX     : recopié de PROCESSING_HISTORY.NAME
-- ADRESSE 		: recopié de PROCESSING_HISTORY.DATA_TRANSFERT_ADDRESS
-- MODE_TRANSFERT  : recopié de PROCESSING_HISTORY.DATA_TRANSFERT_TYPE
-- DATE_TRANSFERT  : recopié de PROCESSING_HISTORY.DATA_TRANSFERT_DATE
-- DATE_TRAITEMENT  : recopié de PROCESSING_HISTORY.PROCESSING_DATE
-- ETAT  		: Correspondances établie à partir de PROCESSING_HISTORY.PROCESSING_STATUS_FK
--                  - Si WAITING_EXECUTION -> E (a Envoyer)
--                  - Si WAITING_ACKNOWLEDGE -> A (attente AR)
--                  - Si SUCCESS sur un traitement SIH_ENVOI -> T (Transmis)
--                  - Si SUCCESS sur un autre traitement que SIH_ENVOI -> C (Chargé)
--------------------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW "HIS_FLUX" (
  ID,
  TYPE_FLUX,
  NOM_FLUX,
  ADRESSE,
  MODE_TRANSFERT,
  DATE_TRANSFERT,
  DATE_TRAITEMENT,
  ETAT    
  ) as      
select
  PH.ID,
  DECODE(PH.PROCESSING_TYPE_FK,'SIH_ENVOI',PH_OTHER_TYPE.PROCESSING_TYPE_FK, PH.PROCESSING_TYPE_FK) as TYPE_FLUX,
  PH.NAME as NOM_FLUX,
  PH.data_transfert_address as ADRESSE, 
  PH.data_transfert_type as MODE_TRANSFERT,
  PH.data_transfert_date as DATE_TRANSFERT,
  NVL(PH_OTHER_TYPE.processing_date, PH.processing_date) as DATE_TRAITEMENT,
  case 
    when PH.processing_status_fk = 'SUCCESS' and PH.PROCESSING_TYPE_FK = 'SIH_ENVOI' then 'T'
    when PH.processing_status_fk = 'WAITING_ACKNOWLEDGE' and PH.PROCESSING_TYPE_FK = 'SIH_ENVOI' then 'A'
    when PH.processing_status_fk = 'WAITING_EXECUTION' and PH.PROCESSING_TYPE_FK = 'SIH_ENVOI' then 'E'
    else 'C'
  end as ETAT
from
  PROCESSING_HISTORY PH
  left outer join PROCESSING_HISTORY PH_OTHER_TYPE
    on PH_OTHER_TYPE.NAME = PH.NAME 
    and PH_OTHER_TYPE.PROCESSING_TYPE_FK <> PH.PROCESSING_TYPE_FK --'SIH_ENVOI'
    and PH_OTHER_TYPE.ID <> PH.ID
where 
  (PH.PROCESSING_TYPE_FK = 'SIH_ENVOI' and PH_OTHER_TYPE.ID is not null)
  or
  (PH.PROCESSING_TYPE_FK <> 'SIH_ENVOI' and PH_OTHER_TYPE.ID is null)
  --and PH_ENVOI.name='SACAPT201001220735.zip'
;
/

create or replace
TRIGGER TR_HIS_FLUX
INSTEAD OF INSERT OR UPDATE OR DELETE ON HIS_FLUX
FOR EACH ROW 
DECLARE 
  L_DUPLICATE_PROCESSING_HISTORY NUMBER;
  L_EXISTS_PROCESSING_HISTORY NUMBER;
  L_PROCESSING_STATUS_FK VARCHAR2(40);
  L_PROCESSING_TYPE_FK VARCHAR2(40);
BEGIN

  -- Si insertion demandée  
  if (INSERTING) then
  
    -- Si flux d'exportation
    if (:new.ETAT = 'E' or :new.ETAT = 'A' or :new.ETAT = 'T') then
    
      -- On regarde si la contrainte d'unicité est respectée
      select count(*) into L_DUPLICATE_PROCESSING_HISTORY
      from PROCESSING_HISTORY
      where 1=1
        and NAME = :new.NOM_FLUX
        and PROCESSING_TYPE_FK = 'SIH_ENVOI'
        and DATA_TRANSFERT_ADDRESS = :new.ADRESSE;
        
      if (L_DUPLICATE_PROCESSING_HISTORY > 0) then
        raise_application_error(-20101, 'ORA-00001: violation de contrainte unique (SIHDBA.PK_HISTO_SEQUENCE)');
      end if;
      
      -- On regarde si le traitement d'export est déjà présent
      select count(*) into L_EXISTS_PROCESSING_HISTORY
      from PROCESSING_HISTORY
      where 1=1
        and NAME = :new.NOM_FLUX
        and PROCESSING_TYPE_FK = :new.TYPE_FLUX
        and PROCESSING_STATUS_FK = 'SUCCESS';
        
      -- La ligne sur le traitement existe déjà, donc ne pas en insérer une nouvelle
      if (L_EXISTS_PROCESSING_HISTORY > 0) then
      
        -- Mise à jour de la ligne du traitement
        update PROCESSING_HISTORY set
          PROCESSING_DATE = :new.DATE_TRAITEMENT,
          DATA_TRANSFERT_TYPE = null/*Sera repris dans la ligne SIH_ENVOI*/,
          DATA_TRANSFERT_DATE = null/*Sera repris dans la ligne SIH_ENVOI*/,
          DATA_TRANSFERT_ADDRESS = null/*Sera repris dans la ligne SIH_ENVOI*/,
          CONFIGURATION = null,
          XML_CONFIGURATION = null,
          PROCESSING_TYPE_FK = L_PROCESSING_TYPE_FK,
          PROCESSING_STATUS_FK ='SUCCESS'
        where 
          ID = :old.ID;
      
      -- Le traitement n'a pas encore été inséré    
      else    
        insert into PROCESSING_HISTORY (
          ID,
          NAME,
          PROCESSING_DATE,
          DATA_TRANSFERT_TYPE,
          DATA_TRANSFERT_DATE,
          DATA_TRANSFERT_ADDRESS,
          CONFIGURATION,
          XML_CONFIGURATION,
          PROCESSING_TYPE_FK,
          PROCESSING_STATUS_FK
        )
        values(
          :new.ID,
          :new.NOM_FLUX,
          :new.DATE_TRAITEMENT,
          null/*MODE_TRANSFERT*/,
          null/*DATE_TRANSFERT*/,
          null/*ADRESSE*/,
          null/*CONFIGURATION*/,
          null/*XML_CONFIGURATION*/,      
          :new.TYPE_FLUX/*PROCESSING_TYPE_FK*/,
          'SUCCESS'/*PROCESSING_STATUS_FK - seuls les traitemens OK sont inséré, sous HIS_FLUX*/
        );
      end if;
      
      insert into PROCESSING_HISTORY (
        ID,
        NAME,
        PROCESSING_DATE,
        DATA_TRANSFERT_TYPE,
        DATA_TRANSFERT_DATE,
        DATA_TRANSFERT_ADDRESS,
        CONFIGURATION,
        XML_CONFIGURATION,
        PROCESSING_TYPE_FK,
        PROCESSING_STATUS_FK
      )
      values(
        :new.ID,
        :new.NOM_FLUX,
        :new.DATE_TRAITEMENT,
        :new.MODE_TRANSFERT,
        :new.DATE_TRANSFERT,
        :new.ADRESSE,
        null/*CONFIGURATION*/,
        null/*XML_CONFIGURATION*/,      
        'SIH_ENVOI' /*PROCESSING_TYPE_FK*/,        
        case /*PROCESSING_STATUS_FK*/
          when :new.ETAT = 'E' then 'WAITING_EXECUTION'
          when :new.ETAT = 'A' then 'WAITING_ACKNOWLEDGE'
          when :new.ETAT = 'T' then 'SUCCESS'
        end
      );
      
    -- Si pas un traitement d'expiortation du flux : on insère dans tous les cas
    else
      insert into PROCESSING_HISTORY (
        ID,
        NAME,
        PROCESSING_DATE,
        DATA_TRANSFERT_TYPE,
        DATA_TRANSFERT_DATE,
        DATA_TRANSFERT_ADDRESS,
        CONFIGURATION,
        XML_CONFIGURATION,
        PROCESSING_TYPE_FK,
        PROCESSING_STATUS_FK
      )
      values(
        :new.ID,
        :new.NOM_FLUX,
        :new.DATE_TRAITEMENT,
        :new.MODE_TRANSFERT,
        :new.DATE_TRANSFERT,
        :new.ADRESSE,
        null/*CONFIGURATION*/,
        null/*XML_CONFIGURATION*/,      
        :new.TYPE_FLUX/*PROCESSING_TYPE_FK*/,
        'SUCCESS'/*PROCESSING_STATUS_FK - seuls les traitemens OK sont inséré, sous HIS_FLUX*/
      );
    end if;
  
  -- Si mise à jour demandée  
  elsif (UPDATING) then
  
    if (:new.ETAT = 'E' or :new.ETAT = 'A' or :new.ETAT = 'T') then
      L_PROCESSING_TYPE_FK := 'SIH_ENVOI';
      
      if (:new.ETAT = 'E') then
        L_PROCESSING_STATUS_FK := 'WAITING_EXECUTION';
      elsif (:new.ETAT = 'A') then
        L_PROCESSING_STATUS_FK := 'WAITING_ACKNOWLEDGE';
      else
        L_PROCESSING_STATUS_FK := 'SUCCESS'; 
      end if;
      
    else
      L_PROCESSING_TYPE_FK := :new.TYPE_FLUX;
      L_PROCESSING_STATUS_FK := 'SUCCESS';
      
      -- Pour ne pas introduire d'incohérence, on vérifie qu'une flux anciennement en Export ne passe en Import
      if (:old.ETAT = 'E' or :old.ETAT = 'A' or :old.ETAT = 'T') then
        raise_application_error(-20101, 'Une ligne d''historique HIS_FLUX indiquant une exportation (ETAT=E ou A ou T) ne pas etre changée en importation (ETAT=C). Supprimer d''abord la ligne, avant recréation.');
      end if;
    end if;
    
    update PROCESSING_HISTORY set
      NAME = :new.NOM_FLUX,
      PROCESSING_DATE = :new.DATE_TRAITEMENT,
      DATA_TRANSFERT_TYPE = :new.MODE_TRANSFERT,
      DATA_TRANSFERT_DATE = :new.DATE_TRANSFERT,
      DATA_TRANSFERT_ADDRESS = :new.ADRESSE,
      CONFIGURATION = null,
      XML_CONFIGURATION = null,
      PROCESSING_TYPE_FK = L_PROCESSING_TYPE_FK,
      PROCESSING_STATUS_FK =L_PROCESSING_STATUS_FK
    where 
      ID = :old.ID;
    
  -- Si suppression demandée  
  elsif (DELETING) then
  
    delete PROCESSING_HISTORY where id=:old.ID;
    
    -- On regarde si d'autre demande d'envoi sont présentes
    select count(*) into L_EXISTS_PROCESSING_HISTORY
    from PROCESSING_HISTORY
    where 1=1
      and NAME = :old.NOM_FLUX
      and PROCESSING_TYPE_FK = 'SIH_ENVOI'
      and PROCESSING_STATUS_FK in('SUCCESS', 'WAITING_EXECUTION', 'WAITING_ACKNOWLEDGE');
      
    -- Si pas d'autres demande d'envoi sur le flux, alors on supprime également la ligne du traitement d'export
    if (L_EXISTS_PROCESSING_HISTORY = 0) then
      delete PROCESSING_HISTORY
      where 1=1
        and NAME = :old.NOM_FLUX
        and PROCESSING_TYPE_FK = :old.TYPE_FLUX
        and PROCESSING_STATUS_FK = 'SUCCESS';
    end if;
  end if;
END;
/

CREATE OR REPLACE FORCE VIEW "DATA_SYNCHRONIZATION" (
  "ID",
	"TABLE_NAME",
	"UPDATE_DATE",
	"VESSEL_FK",
	"OBJECT_ID"   
  ) as
select
   ID,
   OBJECT_TYPE_FK,
   UPDATE_DATE,
   VESSEL_FK,
   OBJECT_ID
from DELETED_ITEM_HISTORY;
/

create or replace
TRIGGER TR_DATA_SYNCHRONIZATION
INSTEAD OF INSERT OR UPDATE ON DATA_SYNCHRONIZATION
FOR EACH ROW 
DECLARE 
  L_OBJECT_TYPE_EXISTS NUMBER;
BEGIN
  -- On regarde si le type d'objet existe bien déjà
  select count(*) into L_OBJECT_TYPE_EXISTS
  from OBJECT_TYPE
  where 1=1
    and code = :new.TABLE_NAME;
    
  -- Si le type d'objet n'existe pas, on l'insert dans OBJECT_TYPE
  if (L_OBJECT_TYPE_EXISTS = 0) then
     insert into  OBJECT_TYPE (code, name) values(:new.TABLE_NAME, :new.TABLE_NAME);
  end if; 
      
  -- Si insertion demandée  
  if (INSERTING) then
    insert into DELETED_ITEM_HISTORY (id, OBJECT_TYPE_FK, UPDATE_DATE, VESSEL_FK,OBJECT_ID) 
    values(:new.ID, :new.TABLE_NAME, :new.UPDATE_DATE, :new.VESSEL_FK, :new.OBJECT_ID);
  
  elsif(UPDATING) then
  
    update DELETED_ITEM_HISTORY
    set
      OBJECT_TYPE_FK=:new.TABLE_NAME,
      UPDATE_DATE=:new.UPDATE_DATE,
      VESSEL_FK=:new.VESSEL_FK,
      OBJECT_ID=:new.OBJECT_ID
    where ID=:old.ID;
  end if;
end;
/

-- --------------------------------------------------------------------------
--
-- Keep a backward compatibility in from version 3.1.2 with 3.1.1 :
-- => creation des vues GROUP_METIER_xx,
--               pour compatibilité avec la version 3.1.1 utilisée par 
--               Recopesca-console
-- --------------------------------------------------------------------------
create or replace VIEW METIER_GROUP as 
select 
  G.ID,
  G.LABEL,
  G.NAME,
  G.UPDATE_DATE,
  G.STATUS_FK, 
  G.GROUPING_CLASSIFICATION_FK as METIER_GROUP_CLASSIFICATION_FK,
  G.GROUPING_LEVEL_FK as METIER_GROUP_LEVEL_FK
from
  GROUPING G, GROUPING_CLASSIFICATION GC
where 
  G.GROUPING_CLASSIFICATION_FK = GC.ID
  and GC.OBJECT_TYPE_FK='METIER';
    
create or replace VIEW METIER_GROUP2METIER as 
select 
  GI.GROUPING_FK as METIER_GROUP_FK,
  GI.OBJECT_ID as METIER_FK
from
  GROUPING G,
  GROUPING_CLASSIFICATION GC,
  GROUPING_ITEM GI
where 
  GC.OBJECT_TYPE_FK='METIER'
  and G.GROUPING_CLASSIFICATION_FK = GC.ID
  and GI.GROUPING_FK = G.ID;

create or replace VIEW METIER_GROUP_CLASSIFICATION as
select 
  GC.ID,
  GC.NAME,
  GC.DESCRIPTION,
  GC.UPDATE_DATE
from
  GROUPING_CLASSIFICATION GC
where 
  GC.OBJECT_TYPE_FK='METIER';
    
create or replace VIEW METIER_GROUP_LEVEL as 
select 
  GL.ID,
  GL.NAME,
  GL.DESCRIPTION,
  GL.UPDATE_DATE,
  GL.GROUPING_CLASSIFICATION_FK as METIER_GROUP_CLASSIFICATION_FK,
  GL.PARENT_GROUPING_LEVEL_FK as PARENT_METIER_GROUP_LEVEL_FK
from
  GROUPING_LEVEL GL,
  GROUPING_CLASSIFICATION GC
where 
  GL.GROUPING_CLASSIFICATION_FK = GC.ID
  and GC.OBJECT_TYPE_FK='METIER';
  
-- --------------------------------------------------------------------------
--
-- Keep a backward compatibility in from version 3.1.3 with 3.1.2 :
-- => creation des vues TRANSCRIBING_xxx, qui ont ‚t‚ remplac‚ par TRANSCRIBING_ITEM
--    (n‚cessaire pour beaucoup de requetes de divers traitements + vues H1)
-- --------------------------------------------------------------------------
create view TRANSCRIBING_LOCATION_LEVEL as 
select
  TIT.TRANSCRIBING_SYSTEM_FK as TRANSCRIBING_SYSTEM_FK,
  TI.OBJECT_ID as LOCATION_LEVEL_FK,
  TI.EXTERNAL_CODE as EXTERNAL_CODE,
  TI.UPDATE_DATE as UPDATE_DATE,
  TIT.TRANSCRIBING_SIDE_FK
from
  TRANSCRIBING_ITEM_TYPE TIT,
  TRANSCRIBING_ITEM TI
where 
  TIT.ID = TI.TRANSCRIBING_ITEM_TYPE_FK
  and TIT.OBJECT_TYPE_FK='LOCATION_LEVEL'
  and TIT.TRANSCRIBING_SYSTEM_FK is not null;

create view TRANSCRIBING_LOCATION as 
select
  TIT.TRANSCRIBING_SYSTEM_FK as TRANSCRIBING_SYSTEM_FK,
  TI.OBJECT_ID as LOCATION_FK,
  TI.EXTERNAL_CODE as EXTERNAL_CODE,
  TI.UPDATE_DATE as UPDATE_DATE,
  TIT.TRANSCRIBING_SIDE_FK
from
  TRANSCRIBING_ITEM_TYPE TIT,
  TRANSCRIBING_ITEM TI
where 
  TIT.ID = TI.TRANSCRIBING_ITEM_TYPE_FK
  and TIT.OBJECT_TYPE_FK='LOCATION'
  and TIT.TRANSCRIBING_SYSTEM_FK is not null
  ;
  
create view TRANSCRIBING_GEAR as 
select
  TIT.TRANSCRIBING_SYSTEM_FK as TRANSCRIBING_SYSTEM_FK,
  TI.OBJECT_ID as GEAR_FK,
  TI.EXTERNAL_CODE as EXTERNAL_CODE,
  TI.UPDATE_DATE as UPDATE_DATE,
  TIT.TRANSCRIBING_SIDE_FK
from
  TRANSCRIBING_ITEM_TYPE TIT,
  TRANSCRIBING_ITEM TI
where 
  TIT.ID = TI.TRANSCRIBING_ITEM_TYPE_FK
  and TIT.OBJECT_TYPE_FK='GEAR'
  and TRANSCRIBING_SYSTEM_FK is not null;
  
create view TRANSCRIBING_TAXON_GROUP as 
select
  TIT.TRANSCRIBING_SYSTEM_FK as TRANSCRIBING_SYSTEM_FK,
  TI.OBJECT_ID as TAXON_GROUP_FK,
  TI.EXTERNAL_CODE as EXTERNAL_CODE,
  TI.UPDATE_DATE as UPDATE_DATE,
  TIT.TRANSCRIBING_SIDE_FK
from
  TRANSCRIBING_ITEM_TYPE TIT,
  TRANSCRIBING_ITEM TI
where 
  TIT.ID = TI.TRANSCRIBING_ITEM_TYPE_FK
  and TIT.OBJECT_TYPE_FK='TAXON_GROUP'
  and TIT.TRANSCRIBING_SYSTEM_FK is not null;
  
create view TRANSCRIBING_METIER as 
select
  TIT.TRANSCRIBING_SYSTEM_FK as TRANSCRIBING_SYSTEM_FK,
  TI.OBJECT_ID as METIER_FK,
  TI.EXTERNAL_CODE as EXTERNAL_CODE,
  TI.UPDATE_DATE as UPDATE_DATE,
  TIT.TRANSCRIBING_SIDE_FK
from
  TRANSCRIBING_ITEM_TYPE TIT,
  TRANSCRIBING_ITEM TI
where 
  TIT.ID = TI.TRANSCRIBING_ITEM_TYPE_FK
  and TIT.OBJECT_TYPE_FK='METIER'
  and TIT.TRANSCRIBING_SYSTEM_FK is not null; 

create view TRANSCRIBING_PMFM as 
select
  TIT.TRANSCRIBING_SYSTEM_FK as TRANSCRIBING_SYSTEM_FK,
  TI.OBJECT_ID as PMFM_FK,
  TI.EXTERNAL_CODE as EXTERNAL_CODE,
  TI.UPDATE_DATE as UPDATE_DATE,
  TIT.TRANSCRIBING_SIDE_FK
from
  TRANSCRIBING_ITEM_TYPE TIT,
  TRANSCRIBING_ITEM TI
where 
  TIT.ID = TI.TRANSCRIBING_ITEM_TYPE_FK
  and TIT.OBJECT_TYPE_FK='PMFM'
  and TIT.TRANSCRIBING_SYSTEM_FK is not null; 

create view TRANSCRIBING_QUALITATIVE_VALUE as 
select
  TIT.TRANSCRIBING_SYSTEM_FK as TRANSCRIBING_SYSTEM_FK,
  QV.ID as QUALITATIVE_VALUE_FK,
  QV.PARAMETER_FK as PARAMETER_FK,
  TI.EXTERNAL_CODE as EXTERNAL_CODE,
  TI.UPDATE_DATE as UPDATE_DATE,
  TIT.TRANSCRIBING_SIDE_FK
from
  TRANSCRIBING_ITEM_TYPE TIT,
  TRANSCRIBING_ITEM TI,
  QUALITATIVE_VALUE QV
where 
  TIT.OBJECT_TYPE_FK='QUALITATIVE_VALUE'
  and TIT.ID = TI.TRANSCRIBING_ITEM_TYPE_FK
  and TI.OBJECT_ID = QV.ID
  and TIT.TRANSCRIBING_SYSTEM_FK is not null; 

create view TRANSCRIBING_PROGRAM as 
select
  TIT.TRANSCRIBING_SYSTEM_FK as TRANSCRIBING_SYSTEM_FK,
  TI.OBJECT_CODE as PROGRAM_FK,
  TI.EXTERNAL_CODE as EXTERNAL_CODE,
  TI.UPDATE_DATE as UPDATE_DATE,
  TIT.TRANSCRIBING_SIDE_FK
from
  TRANSCRIBING_ITEM_TYPE TIT,
  TRANSCRIBING_ITEM TI
where 
  TIT.OBJECT_TYPE_FK='PROGRAM'
  and TIT.ID = TI.TRANSCRIBING_ITEM_TYPE_FK
  and TIT.TRANSCRIBING_SYSTEM_FK is not null; 


--------------------------------------------------------------------------------
-- Vue         : DENORMALIZED_GROUPING_METIER
-- Description : Offre une acces simple aux m‚tiers agr‚g‚s (tables GROUPING_xxx) 
--               correspondant aux m‚tiers SIH (table METIER)
-- 04/09/2011  BL Creation
--------------------------------------------------------------------------------
-- ID         	: identifiant interne (METIER.ID)
-- LABEL       	: mn‚monique du m‚tier (METIER.LABEL)
-- NAME       	: libell‚ du m‚tier (METIER.NAME)
-- xxx_LABEL   	: mn‚monique d'un m‚tier agr‚g‚ de type xxx (xxx = DCR, ATL, etc)
-- xxx_NAME   	: libell‚ d'un m‚tier agr‚g‚ de type xxx (xxx = DCR, ATL, etc)
-- (...) -> autant de colonnes que de classification trouv‚e dans GROUPING,
--          pour grouping_classification_fk = 7 (=Agr‚gation des m‚tiers)
--------------------------------------------------------------------------------
--set serveroutput on format wrapped;
declare
  TYPE_ID integer;
  TYPE_LABEL varchar2(40);
  SUBTYPE_ID integer;
  SUBTYPE_LABEL varchar2(40);
  
  SUFIXE varchar2(30);

  SQL_PART_1 varchar2(10000);
  SQL_PART_2 varchar2(10000);

  cursor cZoneNiveauAgreg is
    select 
      zone_g.id as TYPE_ID, 
      zone_g.label as TYPE_LABEL,
      niveau_g.id as SUBTYPE_ID, 
      niveau_g.label as SUBTYPE_LABEL
    from 
      grouping zone_g,
      grouping niveau_g
    where
      /*Zone d'agregation m‚tier*/
      zone_g.grouping_classification_fk=7
      and zone_g.parent_grouping_fk is null
      /*Niveau d'agregation m‚tier*/
      and niveau_g.parent_grouping_fk = zone_g.id
    order by 
      TYPE_LABEL, SUBTYPE_LABEL
   ;
begin

  SQL_PART_1 := 'CREATE MATERIALIZED VIEW DENORMALIZED_GROUPING_METIER
TABLESPACE SIH2_ADAGIO_REF_DATA
NOCACHE
NOLOGGING
NOPARALLEL
BUILD IMMEDIATE
REFRESH ON DEMAND
AS 
with GROUPING_METIER as (
    select 
      g.label as LABEL,
      g.name as NAME,
      gi.object_id as METIER_FK,
      niveau_g.id as PARENT_GROUPING_FK
    from 
      grouping zone_g,
      grouping niveau_g,
      grouping g, 
      grouping_item gi
    where
      zone_g.grouping_classification_fk=7
      and zone_g.parent_grouping_fk is null
      and niveau_g.parent_grouping_fk = zone_g.id
      and g.parent_grouping_fk = niveau_g.id
      and g.id = gi.grouping_fk
  )
  select 
    m.id           as ID,
    m.label        as METIER_LABEL, 
    m.name         as METIER_NAME,';
  SQL_PART_2 := ' from 
    metier m 
      left outer join GROUPING_METIER gm 
        on gm.metier_fk = m.id
  group by m.id, m.label, m.name';
  OPEN cZoneNiveauAgreg;
  LOOP
    FETCH cZoneNiveauAgreg INTO TYPE_ID, TYPE_LABEL, SUBTYPE_ID, SUBTYPE_LABEL;
    EXIT WHEN cZoneNiveauAgreg%NOTFOUND;
    
    -- cr‚ation d'un suffixe valide pour un nom de table ou de colonne
    SUFIXE := TYPE_LABEL || '_' ||  SUBTYPE_LABEL;
    SUFIXE := REPLACE(SUFIXE, '-');
    SUFIXE := REPLACE(SUFIXE, ' ');

    SQL_PART_1 := SQL_PART_1 || ' max(decode(gm.PARENT_GROUPING_FK,' || SUBTYPE_ID ||', gm.LABEL, null)) as ' || SUFIXE || '_LABEL,';
    SQL_PART_1 := SQL_PART_1 || ' max(decode(gm.PARENT_GROUPING_FK,' || SUBTYPE_ID||', gm.NAME, null)) as ' || SUFIXE || '_NAME,';
    
  END LOOP;
  CLOSE cZoneNiveauAgreg;

  -- remove last comma  
  SQL_PART_1 := SUBSTR(SQL_PART_1, 0, LENGTH(SQL_PART_1)-1);
  
  BEGIN
    -- drop de la view pour la recr‚e ensuite
    EXECUTE IMMEDIATE 'drop MATERIALIZED VIEW DENORMALIZED_GROUPING_METIER';
    dbms_output.put_line('-- drop MATERIALIZED VIEW DENORMALIZED_GROUPING_METIER [success]');
  EXCEPTION
   WHEN OTHERS THEN
     dbms_output.put_line('-- drop MATERIALIZED VIEW DENORMALIZED_GROUPING_METIER [skip]');
  END;
  
  -- create view
  EXECUTE IMMEDIATE (SQL_PART_1 || SQL_PART_2);
  dbms_output.put_line('-- create materialized view DENORMALIZED_GROUPING_METIER [success]');
  DBMS_OUTPUT.put_line(SQL_PART_1 || SQL_PART_2 || ';');
  
end;
/

--------------------------------------------------------------------------------
-- Vue         : DENORMALIZED_TAXON_GROUP_ASFIS
-- Description : dénormalisation des espèces commerciales FAO/ASFIS
-- 19/09/2011  NR Creation
-- 01/02/2012  NR Modification
-- 27/09/2013  NR Modification : ajout PARENT_SCIENTIFIC_NAME, ENGLISH_NAME, lien TAXON_NAME par TAXON_GROUP_HISTORICAL_RECORD
--------------------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW "DENORMALIZED_TAXON_GROUP_ASFIS" as
with
  GROUPING_ISSCAAP as
  (
    select ID, LABEL
    from GROUPING G
    where G.GROUPING_CLASSIFICATION_FK = (select ID from GROUPING_CLASSIFICATION where LABEL='TAXON_GROUP_ISSCAAP')
  ),
  TRANSCRIBING_TAXOCODE as
  (
    select OBJECT_ID, EXTERNAL_CODE
    from TRANSCRIBING_ITEM TI
    where TI.TRANSCRIBING_ITEM_TYPE_FK = (select ID from TRANSCRIBING_ITEM_TYPE where LABEL='FAO-ASFIS.TAXOCODE')
  ),
  TRANSCRIBING_LOCALE_EN as
  (
    select OBJECT_ID, EXTERNAL_CODE
    from TRANSCRIBING_ITEM TI
    where TI.TRANSCRIBING_ITEM_TYPE_FK = (select ID from TRANSCRIBING_ITEM_TYPE where LABEL='FAO-ASFIS.LOCALE_EN')
  )
select
  TG.LABEL as "CODE_3A",
  G.LABEL as "ISSCAAP",
  T_TAXOCODE.EXTERNAL_CODE as "TAXOCODE",
  TG.COMMENTS as "SCIENTIFIC_NAME",
  TG.NAME as "FRENCH_NAME",
  T_EN.EXTERNAL_CODE as "ENGLISH_NAME",
  TG2.LABEL as "PARENT_CODE_3A",
  TG2.COMMENTS AS "PARENT_SCIENTIFIC_NAME",
  TG2.NAME as "PARENT_FRENCH_NAME",
  TN.REFERENCE_TAXON_FK as "REFERENCE_TAXON_FK",
  TN.COMPLETE_NAME as "TAXON_SCIENTIFIC_NAME",
  (
    select COMPLETE_NAME from TAXON_NAME where TAXONOMIC_LEVEL_FK = 'FAMILY' and IS_REFERENT = 1 and rownum = 1
    connect by ID = prior PARENT_TAXON_NAME_FK start with ID = TN.ID
  ) as "TAXON_FAMILY",
  (
    select COMPLETE_NAME from TAXON_NAME where TAXONOMIC_LEVEL_FK = 'ORDO' and IS_REFERENT = 1 and rownum = 1
    connect by ID = prior PARENT_TAXON_NAME_FK start with ID = TN.ID
  ) as "TAXON_ORDER",
  C.NAME as "TAXON_AUTHOR",
  decode(length(rtrim(TG.LABEL, '0123456789')), 1, 'IFREMER', 2, 'IFREMER', 'FAO-ASFIS') as "ORIGINE",
  TG.STATUS_FK as "ACT"
from TAXON_GROUP TG
  left outer join TAXON_GROUP TG2
    on TG.PARENT_TAXON_GROUP_FK = TG2.ID
  left outer join TRANSCRIBING_TAXOCODE T_TAXOCODE
    on TG.ID = T_TAXOCODE.OBJECT_ID
  left outer join TRANSCRIBING_LOCALE_EN T_EN
    on TG.ID = T_EN.OBJECT_ID
  left outer join GROUPING_ITEM GI
    on TG.ID = GI.OBJECT_ID
      and GI.GROUPING_FK in (select ID from GROUPING_ISSCAAP)
  left outer join GROUPING_ISSCAAP G
    on GI.GROUPING_FK = G.ID
  left join TAXON_GROUP_HISTORICAL_RECORD TGHR
    on TG.ID = TGHR.TAXON_GROUP_FK
  left outer join TAXON_NAME TN
    on TGHR.REFERENCE_TAXON_FK = TN.REFERENCE_TAXON_FK
      and TN.IS_REFERENT = 1
  left outer join CITATION C
    on TN.CITATION_FK = C.ID
where 1=1
  and TG.TAXON_GROUP_TYPE_FK=2 -- =Espèces FAO/ASFIS
  and TG.LABEL <> '...' -- familles/ordres
order by TG.LABEL
/


--------------------------------------------------------------------------------
-- Vue         : QUANTIFICATION_MEASUREMENT
-- Description : Vue de compatibilit‚ exploitant QUANTIFICATION_MEASUREMENT_B  (pour Allegro)
-- 20/04/2012  EB Creation
--------------------------------------------------------------------------------
CREATE OR REPLACE VIEW QUANTIFICATION_MEASUREMENT AS
SELECT ID,
  NUMERICAL_VALUE,
  DIGIT_COUNT,
  PRECISION_VALUE,
  CONTROL_DATE,
  VALIDATION_DATE,
  QUALIFICATION_DATE,
  QUALIFICATION_COMMENTS,
  DEPARTMENT_FK,
  PRECISION_TYPE_FK,
  QUALITY_FLAG_FK,
  ANALYSIS_INSTRUMENT_FK,
  NUMERICAL_PRECISION_FK,
  PMFM_FK,
  QUALITATIVE_VALUE_FK,
  AGGREGATION_LEVEL_FK,
  SUBGROUP_NUMBER,
  IS_REFERENCE_QUANTIFICATION,
  NULL AS PRODUCE_FK,
  BATCH_FK,
  ALPHANUMERICAL_VALUE
FROM QUANTIFICATION_MEASUREMENT_B;
/

--------------------------------------------------------------------------------
-- Vue         : SORTING_MEASUREMENT
-- Description : Vue de compatibilit‚ SORTING_MEASUREMENT_B (pour Allegro)
-- 20/04/2012  EB Creation
--------------------------------------------------------------------------------
CREATE OR REPLACE VIEW SORTING_MEASUREMENT AS
SELECT ID,
  NUMERICAL_VALUE,
  DIGIT_COUNT,
  PRECISION_VALUE,
  CONTROL_DATE,
  VALIDATION_DATE,
  QUALIFICATION_DATE,
  QUALIFICATION_COMMENTS,
  DEPARTMENT_FK,
  PRECISION_TYPE_FK,
  QUALITY_FLAG_FK,
  ANALYSIS_INSTRUMENT_FK,
  NUMERICAL_PRECISION_FK,
  PMFM_FK,
  QUALITATIVE_VALUE_FK,
  AGGREGATION_LEVEL_FK,
  RANK_ORDER,
  NULL AS PRODUCE_FK,
  SORTING_BATCH_FK,
  ALPHANUMERICAL_VALUE
FROM SORTING_MEASUREMENT_B;
/
 
--------------------------------------------------------------------------------
-- Vue         : FISHING_TRIP_PUBLIC
-- Description : Vue permettant de securis‚ l'accŠs aux mar‚e VMS
-- 20/04/2012  EB Creation
--------------------------------------------------------------------------------
CREATE OR REPLACE VIEW FISHING_TRIP_PUBLIC AS
SELECT *
FROM FISHING_TRIP
WHERE PROGRAM_FK != 'VMS';
/
   
--------------------------------------------------------------------------------
-- Vue         : VESSEL_POSITION_COMPLETE
-- Description : Vue permettant d'acc‚der … l'ensemble des positions (publiques et priv‚es)
-- 20/04/2012  EB Creation
--------------------------------------------------------------------------------
CREATE OR REPLACE VIEW VESSEL_POSITION_COMPLETE AS
  SELECT * FROM VESSEL_POSITION
UNION ALL
  SELECT * FROM VESSEL_POSITION_VMS;
/

--------------------------------------------------------------------------------
-- Vue         : DENORMALIZED_SECTEUR_DCR
-- Description : Matrice des secteurs DCR  (mantis #12495)
-- 24/05/2013  : AG Creation
--------------------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW DENORMALIZED_SECTEUR_DCR AS
WITH liste AS
  ( SELECT DISTINCT sec.id --liste des secteurs à hierarchiser
  FROM grouping gro
  INNER JOIN grouping_item gri
  ON gri.grouping_fk=gro.id
  INNER JOIN location sec
  ON sec.id=gri.object_id
  INNER JOIN grouping_classification grc
  ON gro.grouping_classification_fk=grc.id
  AND grc.label                    ='TERRESTRIAL_LOCATION_DCR'
  ),
  hierarchie AS
  (SELECT sec.id, -- hierarchie  secteur <-> zones DCF
    tri.external_code                         AS niv,
    to_number(trl.external_code)              AS tsec_cod,
    tsec.name                                 AS tsec_lib,
    sec.label                                 AS sect_cod,
    sec.name                                  AS sect_lib,
    DECODE(niv,'65','SPR','66','R','67','SR') AS niv_p,
    to_number(niv)                            AS tsec_cod_p,
    niv_lib                                   AS tsec_lib_p,
    niveau.label                              AS sect_cod_p,
    niveau.name                               AS sect_lib_p
  FROM
    (SELECT CONNECT_BY_ROOT gro.id AS root,
      gro.label                    AS label,
      gro.name                     AS name,
      grl.name                     AS NIV,
      grl.description              AS NIV_lib
    FROM grouping gro
    INNER JOIN grouping_level grl
    ON gro.grouping_level_fk=grl.id
    INNER JOIN grouping_classification grc
    ON gro.grouping_classification_fk         =grc.id
    AND grc.label                             ='TERRESTRIAL_LOCATION_DCR'
      START WITH grl.name                    IN ('65','66','67')
      CONNECT BY (prior gro.parent_grouping_fk= gro.id)
    ) niveau
  INNER JOIN grouping_item gri
  ON gri.grouping_fk=niveau.root
  INNER JOIN location sec
  ON sec.id=object_id
  INNER JOIN location_level tsec
  ON tsec.id=sec.location_level_fk
  INNER JOIN transcribing_item trl
  ON tsec.id=trl.object_id
  INNER JOIN transcribing_item_type tit
  ON tit.id    =trl.transcribing_item_type_fk
  AND tit.label='H1-DRB_TYPE_SECTEUR.TSECT_COD'
  LEFT JOIN (transcribing_item tri
  INNER JOIN transcribing_item_type trit
  ON trit.id       =tri.transcribing_item_type_fk
  AND trit.label   ='DCF-GEO_STRAT.LEVEL_CODE' )
  ON tsec.id       =tri.object_id
  WHERE sec.label <> '...'
  UNION
  SELECT DISTINCT sec.id, -- hierarchie  secteur <-> secteur
    tri.external_code,
    to_number(trl.external_code),
    tsec.name,
    sec.label,
    sec.name,
    tri_p.external_code,
    to_number(trl_p.external_code),
    tsec_p.name,
    first_value(sec_p.label) over (partition BY sec.id,tsec_p.name order by lh.child_surface_ratio DESC),
    first_value(sec_p.name) over (partition BY sec.id,tsec_p.name order by lh.child_surface_ratio DESC)
  FROM liste
  INNER JOIN location sec
  ON sec.id=liste.id
  INNER JOIN location_level tsec
  ON tsec.id=sec.location_level_fk
  INNER JOIN transcribing_item trl
  ON tsec.id=trl.object_id
  INNER JOIN transcribing_item_type tit
  ON tit.id    =trl.transcribing_item_type_fk
  AND tit.label='H1-DRB_TYPE_SECTEUR.TSECT_COD'
  INNER JOIN location_hierarchy lh
  ON lh.child_location_fk=sec.id
  INNER JOIN location sec_p
  ON lh.parent_location_fk=sec_p.id
  INNER JOIN location_level tsec_p
  ON tsec_p.id=sec_p.location_level_fk
  INNER JOIN transcribing_item trl_p
  ON tsec_p.id=trl_p.object_id
  INNER JOIN transcribing_item_type tit_p
  ON tit_p.id    =trl_p.transcribing_item_type_fk
  AND tit_p.label='H1-DRB_TYPE_SECTEUR.TSECT_COD'
  LEFT JOIN (transcribing_item tri_p
  INNER JOIN transcribing_item_type trit_p
  ON trit_p.id    =tri_p.transcribing_item_type_fk
  AND trit_p.label='DCF-GEO_STRAT.LEVEL_CODE' )
  ON tsec_p.id    =tri_p.object_id
  LEFT JOIN (transcribing_item tri
  INNER JOIN transcribing_item_type trit
  ON trit.id       =tri.transcribing_item_type_fk
  AND trit.label   ='DCF-GEO_STRAT.LEVEL_CODE' )
  ON tsec.id       =tri.object_id
  WHERE sec.label <> '...'
  AND sec_p.label <> '...'
  ),
  infos AS
  (SELECT sec.id, --liste des secteurs à hierarchiser
    trl.external_code AS TSEC_COD,
    tsec.name         AS TSEC_LIB,
    sec.label         AS SECT_COD,
    sec.name          AS SECT_LIB
  FROM liste
  INNER JOIN location sec
  ON sec.id=liste.id
  INNER JOIN location_level tsec
  ON tsec.id=sec.location_level_fk
  INNER JOIN transcribing_item trl
  ON tsec.id=trl.object_id
  INNER JOIN transcribing_item_type tit
  ON tit.id    =trl.transcribing_item_type_fk
  AND tit.label='H1-DRB_TYPE_SECTEUR.TSECT_COD'
  )
SELECT DECODE(L1.sect_cod_p,'27','ICES','37','CGFM','34','COPA','21','NAFO','58','CCAM','48','CCAM','88','CCAM','AUTR') AS STRG_COD,
  to_number(lst.TSEC_COD)                                                                                               AS TSECT_COD,
  lst.TSEC_LIB                                                                                                          AS TSECT_LIB,
  TO_CHAR(lst.SECT_COD)                                                                                                 AS SECT_COD,
  lst.SECT_LIB,
  SPR.sect_cod_p           AS SUPRA_REGION_COD,
  SPR.sect_lib_p           AS SUPRA_REGION_LIB,
  R.sect_cod_p             AS REGION_COD,
  R.sect_lib_p             AS REGION_LIB,
  to_number(SR.tsec_cod_p) AS SOUS_REGION_TSECT_COD,
  SR.tsec_lib_p            AS SOUS_REGION_TSECT_LIB,
  SR.sect_cod_p            AS SOUS_REGION_COD,
  SR.sect_lib_p            AS SOUS_REGION_LIB,
  to_number(L1.tsec_cod_p) AS LEVEL1_TSECT_COD,
  L1.tsec_lib_p            AS LEVEL1_TSECT_LIB,
  L1.sect_cod_p            AS LEVEL1_SECT_COD,
  L1.sect_lib_p            AS LEVEL1_SECT_LIB,
  to_number(L2.tsec_cod_p) AS LEVEL2_TSECT_COD,
  L2.tsec_lib_p            AS LEVEL2_TSECT_LIB,
  L2.sect_cod_p            AS LEVEL2_SECT_COD,
  L2.sect_lib_p            AS LEVEL2_SECT_LIB,
  to_number(L3.tsec_cod_p) AS LEVEL3_TSECT_COD,
  L3.tsec_lib_p            AS LEVEL3_TSECT_LIB,
  L3.sect_cod_p            AS LEVEL3_SECT_COD,
  L3.sect_lib_p            AS LEVEL3_SECT_LIB,
  to_number(L4.tsec_cod_p) AS LEVEL4_TSECT_COD,
  L4.tsec_lib_p            AS LEVEL4_TSECT_LIB,
  L4.sect_cod_p            AS LEVEL4_SECT_COD,
  L4.sect_lib_p            AS LEVEL4_SECT_LIB,
  to_number(L5.tsec_cod_p) AS LEVEL5_TSECT_COD,
  L5.tsec_lib_p            AS LEVEL5_TSECT_LIB,
  L5.sect_cod_p            AS LEVEL5_SECT_COD,
  L5.sect_lib_p            AS LEVEL5_SECT_LIB
FROM infos lst
LEFT JOIN hierarchie SPR
ON SPR.niv_p='SPR'
AND SPR.id  =lst.id
LEFT JOIN hierarchie R
ON R.niv_p='R'
AND R.id  =lst.id
LEFT JOIN hierarchie SR
ON SR.niv_p='SR'
AND SR.id  =lst.id
LEFT JOIN hierarchie L1
ON L1.niv_p='L1'
AND L1.id  =lst.id
LEFT JOIN hierarchie L2
ON L2.niv_p='L2'
AND L2.id  =lst.id
LEFT JOIN hierarchie L3
ON L3.niv_p='L3'
AND L3.id  =lst.id
LEFT JOIN hierarchie L4
ON L4.niv_p='L4'
AND L4.id  =lst.id
LEFT JOIN hierarchie L5
ON L5.niv_p='L5'
AND L5.id  =lst.id;

-- -----------------------------------------------------------------------------
-- 06/02/2013 EM Vue DENORMALIZED_PMFM (Mantis 15052)
-- 14/10/2015 EM Ajout valeurs qualitative associées au PMFM et au PARAMETRE (Mantis 26484)
-- 10/03/2016 EM Correction vue (Mantis 26484)
-- -----------------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW "SIH2_ADAGIO_DBA"."DENORMALIZED_PMFM" ("PMFM_FK", "PMFM_IS_QUALITATIVE", "PMFM_STATUS_FK", "PARAMETER_FK", "PARAMETER_NAME", "PARAMETER_STATUS_FK", "PARAMETER_COMMENTS", "PARAMETER_GROUP_FK", "PARAMETER_GROUP_NAME", "PARAMETER_GROUP_STATUS_FK", "MATRIX_FK", "MATRIX_NAME", "FRACTION_FK", "FRACTION_NAME", "FRACTION_STATUS_FK", "METHOD_FK", "METHOD_NAME", "METHOD_DESCRIPTION", "METHOD_STATUS_FK", "UNIT_FK", "UNIT_NAME", "UNIT_STATUS_FK", "PMFM_PRECISION", "AGGREGATION_LEVEL_FK", "AGGREGATION_LEVEL_NAME") AS 
  SELECT DISTINCT
  PMFM.ID                                   as PMFM_FK, 
  P.IS_QUALITATIVE                          as PMFM_IS_QUALITATIVE,
  PMFM.STATUS_FK                            as PMFM_STATUS_FK,
  P.CODE                                    as PARAMETER_FK, 
  P.NAME                                    as PARAMETER_NAME, 
  P.STATUS_FK                               as PARAMETER_STATUS_FK,
  P.COMMENTS                                as PARAMETER_COMMENTS, 
  PG.ID                                     as PARAMETER_GROUP_FK,
  PG.NAME                                   as PARAMETER_GROUP_NAME, 
  PG.STATUS_FK                              as PARAMETER_GROUP_STATUS_FK,
  M.ID                                      as MATRIX_FK,
  M.NAME                                    as MATRIX_NAME,
  F.ID                                      as FRACTION_FK, 
  F.NAME                                    as FRACTION_NAME,
  F.STATUS_FK                               as FRACTION_STATUS_FK,
  ME.ID                                     as METHOD_FK,  
  ME.NAME                                   as METHOD_NAME, 
  ME.DESCRIPTION                            as METHOD_DESCRIPTION,
  ME.STATUS_FK                              as METHOD_STATUS_FK,
  U.ID                                      as UNIT_FK,
  U.NAME                                    as UNIT_NAME,
  U.STATUS_FK                               as UNIT_STATUS_FK,  
  PMFM.PRECISION                            as PMFM_PRECISION,
  ag.id                                     as AGGREGATION_LEVEL_FK,
  ag.name                                   as AGGREGATION_LEVEL_NAME
  
FROM PMFM
     join PARAMETER P
          join PARAMETER_GROUP PG
            on P.PARAMETER_GROUP_FK = PG.ID
       on P.CODE= PMFM.PARAMETER_FK
     join MATRIX M
       on PMFM.MATRIX_FK=M.ID
     join FRACTION F
       on PMFM.FRACTION_FK=F.ID
     join METHOD ME
       on PMFM.METHOD_FK=ME.ID
     left join UNIT U
       on PMFM.UNIT_FK=U.ID
     left join AGGREGATION_LEVEL ag
       on PMFM.AGGREGATION_LEVEL_FK = ag.id
     left join PMFM2QUALITATIVE_VALUE p2q
       on PMFM.ID = p2q.PMFM_FK
ORDER BY PMFM.ID;


-- -----------------------------------------------------------------------------
-- 06/02/2013 EM Vue DENORMALIZED_QUALITATIVE_VALUE (Mantis 15052)
-- 10/03/2016 EM Correction vue (Mantis 26484)
-- -----------------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW "SIH2_ADAGIO_DBA"."DENORMALIZED_QUALITATIVE_VALUE" ("PMFM_FK", "PMFM_IS_QUALITATIVE", "PMFM_STATUS_FK", "PARAMETER_FK", "PARAMETER_NAME", "PARAMETER_STATUS_FK", "PARAMETER_COMMENTS", "PARAMETER_GROUP_FK", "PARAMETER_GROUP_NAME", "PARAMETER_GROUP_STATUS_FK", "MATRIX_FK", "MATRIX_NAME", "FRACTION_FK", "FRACTION_NAME", "FRACTION_STATUS_FK", "METHOD_FK", "METHOD_NAME", "METHOD_DESCRIPTION", "METHOD_STATUS_FK", "QUALITATIVE_VALUE_FK", "QUALITATIVE_VALUE_NAME", "QUALITATIVE_VALUE_DESCRIPTION", "QUALITATIVE_VALUE_STATUS_FK") AS 
  SELECT 
  PMFM.ID                                   as PMFM_FK, 
  P.IS_QUALITATIVE                          as PMFM_IS_QUALITATIVE,
  PMFM.STATUS_FK                            as PMFM_STATUS_FK,
  P.CODE                                    as PARAMETER_FK, 
  P.NAME                                    as PARAMETER_NAME, 
  P.STATUS_FK                               as PARAMETER_STATUS_FK,
  P.COMMENTS                                as PARAMETER_COMMENTS,
  PG.ID                                     as PARAMETER_GROUP_FK,
  PG.NAME                                   as PARAMETER_GROUP_NAME, 
  PG.STATUS_FK                              as PARAMETER_GROUP_STATUS_FK,
  M.ID                                      as MATRIX_FK,
  M.NAME                                    as MATRIX_NAME,
  F.ID                                      as FRACTION_FK, 
  F.NAME                                    as FRACTION_NAME,
  F.STATUS_FK                               as FRACTION_STATUS_FK,
  ME.ID                                     as METHOD_FK,  
  ME.NAME                                   as METHOD_NAME, 
  ME.DESCRIPTION                            as METHOD_DESCRIPTION,
  ME.STATUS_FK                              as METHOD_STATUS_FK,
  QV.ID                                     as QUALITATIVE_VALUE_FK,
  QV.NAME                                   as QUALITATIVE_VALUE_NAME, 
  QV.DESCRIPTION                            as QUALITATIVE_VALUE_DESCRIPTION,
  QV.STATUS_FK                              as QUALITATIVE_VALUE_STATUS_FK
FROM PMFM
     join PARAMETER P
          join PARAMETER_GROUP PG
            on P.PARAMETER_GROUP_FK = PG.ID
       on P.CODE= PMFM.PARAMETER_FK
     join MATRIX M
       on PMFM.MATRIX_FK=M.ID
     join FRACTION F
       on PMFM.FRACTION_FK=F.ID
     join METHOD ME
       on PMFM.METHOD_FK=ME.ID
     join PMFM2QUALITATIVE_VALUE p2q
          join QUALITATIVE_VALUE QV
            on P2Q.QUALITATIVE_VALUE_FK=QV.ID
       on PMFM.ID=P2Q.PMFM_FK
ORDER BY PMFM_FK, QUALITATIVE_VALUE_FK;

----------------------------------------------
-- 10/03/2016 EM Correction vue (Mantis 26484)
----------------------------------------------
CREATE OR REPLACE FORCE VIEW "SIH2_ADAGIO_DBA"."DENORMALIZED_PARAMETER" ("PARAMETER_FK", "PARAMETER_NAME", "PARAMETER_STATUS_FK", "PARAMETER_COMMENTS", "PARAMETER_IS_QUALITATIVE","PARAMETER_IS_TAXINOMIC","PARAMETER_IS_CALCULATED","PARAMETER_GROUP_FK", "PARAMETER_GROUP_NAME", "PARAMETER_GROUP_STATUS_FK", "QUALITATIVE_VALUE_FK", "QUALITATIVE_VALUE_NAME", "QUALITATIVE_VALUE_DESCRIPTION", "QUALITATIVE_VALUE_STATUS_FK") AS 
SELECT 
  P.CODE                                    as PARAMETER_FK, 
  P.NAME                                    as PARAMETER_NAME, 
  P.STATUS_FK                               as PARAMETER_STATUS_FK,
  P.COMMENTS                                as PARAMETER_COMMENTS, 
  P.IS_QUALITATIVE                          as PARAMETER_IS_QUALITATIVE,
  P.IS_TAXINOMIC                            as PARAMETER_IS_TAXINOMIC,
  P.IS_CALCULATED                           as PARAMETER_IS_CALCULATED,
  PG.ID                                     as PARAMETER_GROUP_FK,
  PG.NAME                                   as PARAMETER_GROUP_NAME, 
  PG.STATUS_FK                              as PARAMETER_GROUP_STATUS_FK,
  
  /* Qualitative values du Parameter */
  PARQV.ID                                  as QUALITATIVE_VALUE_FK,
  PARQV.NAME                                as QUALITATIVE_VALUE_NAME,
  PARQV.DESCRIPTION                         as QUALITATIVE_VALUE_DESCRIPTION,
  PARQV.STATUS_FK                           as QUALITATIVE_VALUE_STATUS_FK  
FROM PARAMETER P
          join PARAMETER_GROUP PG
            on P.PARAMETER_GROUP_FK = PG.ID
          left join QUALITATIVE_VALUE PARQV
            on P.CODE = PARQV.PARAMETER_FK
ORDER BY P.CODE;



-- -----------------------------------------------------------------------------
-- 09/10/2013 EM Vue DENORMALIZED_LOC_SCIENT_CRUIS (Mantis 17341)
-- 12/11/2013 EM Correction vue DENORMALIZED_LOC_SCIENT_CRUIS (Mantis 17341): rajout des critères de niveaux
-- -----------------------------------------------------------------------------

CREATE VIEW DENORMALIZED_LOC_SCIENT_CRUISE
AS
  SELECT L301.LOCATION_LEVEL_FK   AS ZONE_ETUDE_LOC_LEVEL,
      L301.ID    AS ZONE_ETUDE_LOC_ID,
      L301.LABEL AS ZONE_ETUDE_LABEL,
      L301.NAME  AS ZONE_ETUDE_NAME,
      L302.LOCATION_LEVEL_FK        AS STRATE_LOC_LEVEL,
      L302.ID    AS STRATE_LOC_ID,
      L302.LABEL AS STRATE_LABEL,
      L302.NAME  AS STRATE_NAME,
      L303.LOCATION_LEVEL_FK        AS SOUS_STRATE_LOC_LEVEL,
      L303.ID    AS SOUS_STRATE_LOC_ID,
      L303.LABEL AS SOUS_STRATE_LABEL,
      L303.NAME  AS SOUS_STRATE_NAME,
      L304.LOCATION_LEVEL_FK        AS LOCALITE_LOC_LEVEL,
      L304.ID    AS LOCALITE_LOC_ID,
      L304.LABEL AS LOCALITE_LABEL,
      L304.NAME  AS LOCALITE_NAME,
      L305.LOCATION_LEVEL_FK        AS RADIALE_LOC_LEVEL,
      L305.ID    AS RADIALE_LOC_ID,
      L305.LABEL AS RADIALE_LABEL,
      L305.NAME  AS RADIALE_NAME
    FROM LOCATION_ASSOCIATION LA301302,
      LOCATION_ASSOCIATION LA302303,
      LOCATION_ASSOCIATION LA303304,
      LOCATION_ASSOCIATION LA304305,
      LOCATION L301,
      LOCATION L302,
      LOCATION L303,
      LOCATION L304,
      LOCATION L305
    WHERE 1=1
      /* Niveaux */
      AND L301.LOCATION_LEVEL_FK=301
      AND L302.LOCATION_LEVEL_FK=302
      AND L303.LOCATION_LEVEL_FK=303
      AND L304.LOCATION_LEVEL_FK=304
      AND L305.LOCATION_LEVEL_FK=305
      /* Liens */
      AND LA301302.CHILD_LOCATION_FK(+)=LA302303.PARENT_LOCATION_FK
      AND LA302303.CHILD_LOCATION_FK(+)=LA303304.PARENT_LOCATION_FK
      AND LA303304.CHILD_LOCATION_FK(+)=LA304305.PARENT_LOCATION_FK
      /* Parents */
      AND L301.ID=LA301302.PARENT_LOCATION_FK
      AND L302.ID=LA302303.PARENT_LOCATION_FK
      AND L303.ID=LA303304.PARENT_LOCATION_FK
      AND L304.ID=LA304305.PARENT_LOCATION_FK
      /* Children */
      AND L302.ID=LA301302.CHILD_LOCATION_FK
      AND L303.ID=LA302303.CHILD_LOCATION_FK
      AND L304.ID=LA303304.CHILD_LOCATION_FK
    AND L305.ID=LA304305.CHILD_LOCATION_FK;

----------------------------------------------------------
-- 10/10/2013 EM Vue métier DENORMALIZED_WEIGHT_LENGTH_C pour les RTP (Mantis 17885)
-- 21/10/2013 EM Modifications vue métier DENORMALIZED_WEIGHT_LENGTH_C (Mantis 21531: [Table de référence] vue des relation taille-poids)
----------------------------------------------------------

CREATE VIEW DENORMALIZED_WEIGHT_LENGTH_C AS
SELECT	T.REFERENCE_TAXON_FK,
  T.COMPLETE_NAME,
  TI.EXTERNAL_CODE AS TRANS_ALPHIA_ID,
  L.LABEL ZONE_LABEL,
  L.NAME ZONE_NAME,
  LL.ID TYPE_ZONE_CODE,
  LL.NAME TYPE_ZONE_NAME,
  WLC.LENGTH_PARAMETER_FK TYPE_MESURE,
  P.NAME TYPE_MESURE_NAME,
  WLC.CONVERSION_COEFFICIENT_A*DECODE(WLC.LENGTH_UNIT_FK,4 /*cm*/,1,5/*dm*/,10,6/*mm*/,0.1,7/*m*/,100,25/*km*/,100000,0) COEFF_A_EN_CM,
  WLC.CONVERSION_COEFFICIENT_B COEFF_B,
  QV.NAME SEXE,
  WLC.YEAR,
  WLC.START_MONTH,
  WLC.END_MONTH,
  WLC.STATUS_FK RTP_STATUS,
  WLC.DESCRIPTION
FROM WEIGHT_LENGTH_CONVERSION WLC, TAXON_NAME T, LOCATION L, LOCATION_LEVEL LL, QUALITATIVE_VALUE QV, PARAMETER P, TRANSCRIBING_ITEM TI, TRANSCRIBING_ITEM_TYPE TIT
WHERE WLC.REFERENCE_TAXON_FK=T.REFERENCE_TAXON_FK
AND L.ID=WLC.LOCATION_FK
AND L.LOCATION_LEVEL_FK=LL.ID
AND WLC.SEX_QUALITATIVE_VALUE_FK=QV.ID
AND WLC.LENGTH_PARAMETER_FK=P.CODE
AND T.ID = TI.OBJECT_ID (+)
AND TI.TRANSCRIBING_ITEM_TYPE_FK = TIT.ID
AND TIT.LABEL = 'TAXINOMIE-WORMS.ALPHIA_ID';


----------------------------------------------------------
-- 17/02/2014 EB Vue métier DENORMALIZED_TAXON (Mantis 17723)
----------------------------------------------------------

  CREATE OR REPLACE FORCE VIEW DENORMALIZED_TAXON AS 
  select
  rt.id as reference_taxon_fk,
  tn.upper_rank as upper_rank,
  tl.name as taxinonmic_level,
  tn.id as taxon_name_fk,
  tn.name as taxon_name,
  tn.is_referent as is_referent,
  tn.is_obsolete,
  c.id as citation_fk,
  c.name as citation,
  ti_perm.external_code as trans_permanent_code,
  ti_mne.external_code as trans_mnemonique_code,
  ti_alp.external_code as trans_alphia_id,
  tn.parent_taxon_name_fk
from reference_taxon rt
     join taxon_name tn
          join taxonomic_level tl
            on tn.taxonomic_level_fk = tl.code
          left join citation c
            on tn.citation_fk = c.id
          left join transcribing_item ti_perm
              join transcribing_item_type tit_perm
                on ti_perm.transcribing_item_type_fk = tit_perm.id
                and tit_perm.label = 'TAXINOMIE-REFTAX.CODE_PERMANENT'
            on tn.reference_taxon_fk = ti_perm.object_id
          left join transcribing_item ti_mne
              join transcribing_item_type tit_mne
                on ti_mne.transcribing_item_type_fk = tit_mne.id
                and tit_mne.label = 'TAXINOMIE-REFTAX.MNEMONIQUE'
            on tn.reference_taxon_fk = ti_mne.object_id
          left join transcribing_item ti_alp
              join transcribing_item_type tit_alp
                on ti_alp.transcribing_item_type_fk = tit_alp.id
                and tit_alp.label = 'TAXINOMIE-WORMS.ALPHIA_ID'
            on tn.id = ti_alp.object_id
       on rt.id = tn.reference_taxon_fk
order by
  upper_rank,
  is_referent desc,
  taxon_name_fk desc
 ;
 

  
  
----------------------------------------------------------
-- 17/02/2014 EB Vue métier DENORMALIZED_METIER_DCR
----------------------------------------------------------
CREATE OR REPLACE FORCE VIEW DENORMALIZED_METIER_DCR AS
with 
  metier_dcr as (
    select gl.label as grouping_level_label, g.*, ti.external_code as name_en 
    from grouping g
         join grouping_classification gc
           on g.grouping_classification_fk = gc.id
          and gc.label = 'METIER_FLAT'
         join grouping_level gl
           on g.grouping_level_fk = gl.id
           and gl.label like 'DCRL%'
         left join transcribing_item ti
                join transcribing_item_type tit
                 on ti.transcribing_item_type_fk=tit.ID
                and tit.label='LOCALE-EN.METIER-DCF'
           on ti.object_id = g.id
  ),
  translation_metier as (
      SELECT
        ti.OBJECT_ID     as id,
        ti.EXTERNAL_CODE as name_en
      FROM TRANSCRIBING_ITEM ti
           join TRANSCRIBING_ITEM_TYPE tit
             on ti.TRANSCRIBING_ITEM_TYPE_FK=tit.ID
            and tit.LABEL='LOCALE-EN.METIER'
  )
select 
  distinct 
  GRP1.ID           AS DCRL1_GROUPING_FK,
  GRP1.UPDATE_DATE  AS DCRL1_UPDATE_DATE,
  GRP1.LABEL        AS DCRL1_LABEL,
  GRP1.NAME         AS DCRL1_NAME_FR,
  GRP1.NAME_EN      AS DCRL1_NAME_EN,
  GRP2.ID           AS DCRL2_GROUPING_FK,
  GRP2.UPDATE_DATE  AS DCRL2_UPDATE_DATE,
  GRP2.LABEL        AS DCRL2_LABEL,
  GRP2.NAME         AS DCRL2_NAME_FR,
  GRP2.NAME_EN      AS DCRL2_NAME_EN,
  GRP3.ID           AS DCRL3_GROUPING_FK,
  GRP3.UPDATE_DATE  AS DCRL3_UPDATE_DATE,
  GRP3.LABEL        AS DCRL3_LABEL,
  GRP3.NAME         AS DCRL3_NAME_FR,
  GRP3.NAME_EN      AS DCRL3_NAME_EN,
  GRP4.ID           AS DCRL4_GROUPING_FK,
  GRP4.UPDATE_DATE  AS DCRL4_UPDATE_DATE,
  GRP4.LABEL        AS DCRL4_LABEL,
  GRP4.NAME         AS DCRL4_NAME_FR,
  GRP4.NAME_EN      AS DCRL4_NAME_EN,
  GRP5.ID           AS DCRL5_GROUPING_FK,
  GRP5.UPDATE_DATE  AS DCRL5_UPDATE_DATE,
  GRP5.LABEL        AS DCRL5_LABEL,
  GRP5.NAME         AS DCRL5_NAME_FR,
  GRP5.NAME_EN      AS DCRL5_NAME_EN,
  m.id              AS METIER_FK,
  m.update_date     AS METIER_UPDATE_DATE,
  m.label           AS METIER_LABEL,
  m.NAME            AS METIER_NAME_FR,
  m_trans.NAME_EN   AS METIER_NAME_EN,
  m.status_fk       AS METIER_STATUS_FK,
  GRP6.ID           AS DCRL6_GROUPING_FK,
  GRP6.UPDATE_DATE  AS DCRL6_UPDATE_DATE,
  GRP6.LABEL        AS DCRL6_LABEL,
  GRP6.NAME         AS DCRL6_NAME_FR,
  GRP6.NAME_EN      AS DCRL6_NAME_EN,
  GRP6.MIN_VALUE    AS DCRL6_MIN_VALUE,
  GRP6.MAX_VALUE    AS DCRL6_MAX_VALUE
from metier_dcr GRP1
     full outer join metier_dcr GRP2
          full outer join metier_dcr GRP3
               full outer join metier_dcr GRP4
                    full outer join metier_dcr GRP5
                          left join metier_dcr GRP6
                            on grp6.parent_grouping_fk=grp5.ID
                           and grp6.grouping_level_label = 'DCRL6'
                          left join grouping_item gi
                                join metier m
                                     left join translation_metier m_trans
                                      on m.id = m_trans.id
                                  on gi.object_id=m.id
                            on gi.grouping_fk=GRP5.id 
                      on grp5.parent_grouping_fk=grp4.ID
                     and grp5.grouping_level_label = 'DCRL5'
                 on grp4.parent_grouping_fk=grp3.ID
                and grp4.grouping_level_label = 'DCRL4'
            on grp3.parent_grouping_fk=grp2.ID
           and grp3.grouping_level_label = 'DCRL3'
       on grp2.parent_grouping_fk=grp1.ID
      and grp2.grouping_level_label = 'DCRL2'  
where grp1.grouping_level_label = 'DCRL1'
order by DCRL1_LABEL, DCRL2_LABEL,DCRL3_LABEL,DCRL4_LABEL,DCRL5_LABEL,METIER_LABEL;

----------------------------------------------------------
-- 17/03/2014 EB Vue métier DENORMALIZED_SPATIAL_ITEM      
----------------------------------------------------------
CREATE OR REPLACE FORCE VIEW DENORMALIZED_SPATIAL_ITEM ("SPATIAL_ITEM_TYPE_FK", "SPATIAL_ITEM_TYPE_LABEL", "SPATIAL_ITEM_TYPE_NAME", "SPATIAL_ITEM_TYPE_STATUS", "SPATIAL_ITEM_TYPE_UPDATE_DATE", "SPATIAL_ITEM_UPDATE_DATE", "OBJECT_TABLE", "OBJECT_TABLE_FILTER", "OBJECT_ID", "OBJECT_LABEL", "OBJECT_NAME", "OBJECT_STATUS", "MIN_VALUE", "MAX_VALUE", "LOCALIZED_NAME", "LOCALIZED_LOCATION_FK", "LOCALIZED_LOCATION_LEVEL_FK", "LOCALIZED_LOC_CLASS_LEVEL_FK", "LOCALIZED_LOCATION_LABEL", "LOCALIZED_LOCATION_NAME", "LOCALIZED_LOCATION_STATUS") AS 
  select
  distinct
  sit.id              as SPATIAL_ITEM_TYPE_FK,
  sit.label           as SPATIAL_ITEM_TYPE_LABEL,
  sit.name            as SPATIAL_ITEM_TYPE_NAME,
  sit.status_fk       as SPATIAL_ITEM_TYPE_STATUS,
  sit.update_date     as SPATIAL_ITEM_TYPE_UPDATE_DATE,
  si.update_date      as SPATIAL_ITEM_UPDATE_DATE,
  sit.object_type_fk  as OBJECT_TABLE,
  case
    when sit.object_type_fk = 'TAXON_GROUP' then 'TAXON_GROUP_TYPE_FK=' || tg.taxon_group_type_fk
    when sit.object_type_fk = 'GEAR' then 'GEAR_CLASSIFICATION_FK=' || g.gear_classification_fk
    when sit.object_type_fk = 'METIER' then null
    when sit.object_type_fk = 'LOCATION' then 'LOCATION_LEVEL_FK=' || l.location_level_fk || ' and LOCATION_CLASSIFICATION_FK=' || l.location_classification_fk
    when sit.object_type_fk = 'DEPTH_GRADIENT' then null
    when sit.object_type_fk = 'DISTANCE_TO_COAST_GRADIENT' then null
    when sit.object_type_fk = 'NEARBY_SPECIFIC_AREA' then null
    when sit.object_type_fk = 'GROUPING' then 'GROUPING_LEVEL_FK=' || gr.GROUPING_CLASSIFICATION_FK
    else null
  end                 as OBJECT_TABLE_FILTER,
  si.object_id        as OBJECT_ID,
  case
    when sit.object_type_fk = 'TAXON_GROUP' then tg.label
    when sit.object_type_fk = 'GEAR' then g.label
    when sit.object_type_fk = 'METIER' then m.label
    when sit.object_type_fk = 'LOCATION' then l.label
    when sit.object_type_fk = 'DEPTH_GRADIENT' then null
    when sit.object_type_fk = 'DISTANCE_TO_COAST_GRADIENT' then null
    when sit.object_type_fk = 'NEARBY_SPECIFIC_AREA' then null
    when sit.object_type_fk = 'GROUPING' then  gr.label
    else null
  end                as OBJECT_LABEL,
    case
    when sit.object_type_fk = 'TAXON_GROUP' then tg.name
    when sit.object_type_fk = 'GEAR' then g.name
    when sit.object_type_fk = 'METIER' then m.name
    when sit.object_type_fk = 'LOCATION' then l.name
    when sit.object_type_fk = 'DEPTH_GRADIENT' then dg.name
    when sit.object_type_fk = 'DISTANCE_TO_COAST_GRADIENT' then dtcg.name
    when sit.object_type_fk = 'NEARBY_SPECIFIC_AREA' then nsa.name
    when sit.object_type_fk = 'GROUPING' then  gr.name
    else null
  end                as OBJECT_NAME,
  case
    when sit.object_type_fk = 'TAXON_GROUP' then tg.status_fk
    when sit.object_type_fk = 'GEAR' then g.status_fk
    when sit.object_type_fk = 'METIER' then m.status_fk
    when sit.object_type_fk = 'LOCATION' then l.status_fk
    when sit.object_type_fk = 'DEPTH_GRADIENT' then dg.status_fk
    when sit.object_type_fk = 'DISTANCE_TO_COAST_GRADIENT' then dtcg.status_fk
    when sit.object_type_fk = 'NEARBY_SPECIFIC_AREA' then nsa.status_fk
    when sit.object_type_fk = 'GROUPING' then  gr.status_fk
    else null
  end                 as OBJECT_STATUS,
  case
    when sit.object_type_fk = 'GROUPING' then  gr.MIN_VALUE
    else null
  end                 as MIN_VALUE,
  case
    when sit.object_type_fk = 'GROUPING' then  gr.MAX_VALUE
    else null
  end                 as MAX_VALUE,
  si2l.localized_name as LOCALIZED_NAME,
  ll.id                as LOCALIZED_LOCATION_FK,
  ll.location_level_fk as LOCALIZED_LOCATION_LEVEL_FK,
  ll.location_classification_fk as LOCALIZED_LOC_CLASS_LEVEL_FK,
  ll.label             as LOCALIZED_LOCATION_LABEL,
  ll.name              as LOCALIZED_LOCATION_NAME,
  ll.status_fk         as LOCALIZED_LOCATION_STATUS
from spatial_item_type sit
     left join spatial_item si
          left join taxon_group tg
            on tg.id = si.object_id
          left join metier m
            on m.id = si.object_id
          left join gear g
            on g.id = si.object_id
          left join location l
            on l.id = si.object_id
          left join depth_gradient dg
            on dg.id = si.object_id
          left join distance_to_coast_gradient dtcg
            on dtcg.id = si.object_id
          left join nearby_specific_area nsa
            on nsa.id = si.object_id
          left join spatial_item2location si2l
              join location ll
                on si2l.location_fk = ll.id
            on si2l.spatial_item_fk = si.id
          left join grouping gr
            on gr.id = si.object_id
       on si.spatial_item_type_fk = sit.id
order by SPATIAL_ITEM_TYPE_FK,OBJECT_ID;


----------------------------------------------------------
-- 23/04/2014 EB Vue métier DENORMALIZED_ROUND_WEIGHT_CONV (mantis #20139)      
----------------------------------------------------------  
CREATE OR REPLACE FORCE VIEW DENORMALIZED_ROUND_WEIGHT_CONV AS 
select 
  rwc.id,
  rwc.conversion_coefficient,
  rwc.description,
  rwc.start_date,
  rwc.end_date,
  rwc.update_date,
  rwc.taxon_group_fk,
  tg.label as taxon_group_label,
  tg.name as taxon_group_name,
  rwc.location_fk,
  l.location_level_fk,  
  ll.name as location_level_name,
  l.label as location_label,
  l.name as location_name,
  l.status_fk as location_status ,       
  rwc.preserving_fk,
  qv1.name as preserving_name,
  qv1.description as preserving_description,
  rwc.dressing_fk,
  qv2.name as dressing_name,
  qv2.description as dressing_description
from round_weight_conversion rwc
     join taxon_group tg
       on rwc.taxon_group_fk = tg.id
     join location l       
          join location_level ll
            on l.location_level_fk = ll.id
        on rwc.location_fk = l.id
     join qualitative_value qv1
       on rwc.preserving_fk = qv1.id
     join qualitative_value qv2
       on rwc.dressing_fk = qv2.id;
       
----------------------------------------------------------
-- 23/04/2014 EB Vue métier DENORMALIZED_CORPUS (mantis #18432)      
----------------------------------------------------------  
CREATE OR REPLACE VIEW DENORMALIZED_CORPUS AS
select
  ct.id as CORPUS_TYPE_FK,
  ct.name as CORPUS_TYPE_NAME,
  ct.description as CORPUS_TYPE_DESCRIPTION,
  c.id as CORPUS_FK,
  c.NAME as CORPUS_NAME,
  c.DESCRIPTION as CORPUS_DESCRIPTION,
  f.ID as FISHERY_ID,
  f.LABEL as FISHERY_LABEL,
  f.NAME as FISHERY_NAME,
  f.DESCRIPTION as FISHERY_DESCRIPTION_FR,
  tif.external_code as FISHERY_DESCRIPTION_EN,
  rg.id as REG_AREA_FK,
  rgl.id as REG_AREA_LOCATION_FK,
  rgl.location_level_fk as REG_AREA_LOCATION_LEVEL_FK,
  rgl.label as REG_AREA_LOCATION_LABEL,
  ti.external_code as REG_AREA_TRANS_ZONE_FAO,
  rgl.name as REG_AREA_LOCATION_NAME_FR,
  ti2.external_code as REG_AREA_LOCATION_NAME_EN,
  dtcg.id as REG_AREA_DISTANCE2COAST_FK,
  dtcg.name as REG_AREA_DISTANCE2COAST_LABEL,
  nsa.id as REG_AREA_NEARBY_SPE_AREA_FK,
  nsa.name as REG_AREA_NEARBY_SPE_AREA_LABEL,
  dg.id as REG_AREA_DEPTH_GRADIENT_FK,
  dg.name as REG_AREA_DEPTH_GRADIENT_LABEL,
  g.id as GEAR_FK,
  g.label as GEAR_LABEL,
  g.name as GEAR_NAME_FR,
  tig.external_code as GEAR_NAME_EN,
  tg.id as TAXON_GROUP_FK,
  tg.label as TAXON_GROUP_LABEL,
  tg.name as TAXON_GROUP_NAME_FR,
  titg.external_code as TAXON_GROUP_NAME_EN,
  tg.comments as TAXON_GROUP_SCIENTIFIC,
  m.id as METIER_FK,
  m.label as METIER_LABEL,
  m.name as METIER_NAME_FR,
  tim.external_code as METIER_NAME_EN
from corpus c
     join corpus_type ct
       on c.corpus_type_fk = ct.id
     left join corpus2fishery c2f
          join fishery f
               left join regulation_area rg
                    left join location rgl
                         left join transcribing_item ti
                            join transcribing_item_type tit
                              on ti.transcribing_item_type_fk = tit.id
                             and tit.label = 'COST-GEO_STRATE.CODE'
                           on rgl.id = ti.object_id
                         left join transcribing_item ti2
                            join transcribing_item_type tit2
                              on ti2.transcribing_item_type_fk = tit2.id
                             and tit2.label = 'LOCALE-EN.LOCATION'
                           on rgl.id = ti2.object_id
                      on rg.location_fk = rgl.id  
                    left join nearby_specific_area nsa
                      on rg.nearby_specific_area_fk = nsa.id
                    left join depth_gradient dg
                      on rg.depth_gradient_fk = dg.id
                    left join distance_to_coast_gradient dtcg
                      on rg.distance_to_coast_gradient_fk = dtcg.id
                  on f.id = rg.fishery_fk
               left join fishery2taxon_group f2tg
                    join taxon_group tg
                         left join transcribing_item titg
                              join transcribing_item_type tittg
                                on titg.transcribing_item_type_fk = tittg.id
                               and tittg.label = 'FAO-ASFIS.LOCALE_EN'
                            on tg.id = titg.object_id
                      on f2tg.taxon_group_fk = tg.id
                  on f.id = f2tg.fishery_fk
               left join fishery2gear f2g
                    join gear g
                       left join transcribing_item tig
                          join transcribing_item_type titg
                            on tig.transcribing_item_type_fk = titg.id
                           and titg.label = 'LOCALE-EN.GEAR'
                        on g.id = tig.object_id
                      on f2g.gear_fk = g.id
                  on f.id = f2g.fishery_fk
               left join fishery2metier f2m
                    join metier m
                          left join transcribing_item tim
                            join transcribing_item_type titm
                              on tim.transcribing_item_type_fk = titm.id
                             and titm.label = 'LOCALE-EN.METIER'
                          on m.id = tim.object_id
                      on f2m.metier_fk = m.id
                  on f.id = f2m.fishery_fk
              left join transcribing_item tif
                    join transcribing_item_type titf
                      on tif.transcribing_item_type_fk = titf.id
                     and titf.label = 'LOCALE-EN.FISHERY'
                  on f.id = tif.object_id
            on c2f.fishery_fk = f.id
       on c.id = c2f.corpus_fk
--where c.name= 'STOCKH_2014'
; 


----------------------------------------------------------
-- 22/10/2014 EB Vue métier DENORMALIZED_LOC_MARITIME (mantis #21914)      
---------------------------------------------------------- 
CREATE OR REPLACE VIEW DENORMALIZED_LOC_MARITIME AS
with
  hiearchy as (
    select
      lf.id                 as CHILD_LOCATION_FK,
      lf.label              as CHILD_LOCATION_LABEL,
      lf.name               as CHILD_LOCATION_NAME,
      lf.status_fk          as CHILD_LOCATION_STATUS_FK,
      lf.validity_status_fk as CHILD_LOCATION_VALIDITY_FK,
      llf.id                as CHILD_LOCATION_LEVEL_FK,
      llf.NAME              as CHILD_LOCATION_LEVEL_NAME,
      lp.id                 as PARENT_LOCATION_FK,
      lp.label              as PARENT_LOCATION_LABEL,
      lp.name               as PARENT_LOCATION_NAME,
      lp.status_fk          as PARENT_LOCATION_STATUS_FK,
      lp.validity_status_fk as PARENT_LOCATION_VALIDITY_FK,
      llp.id                as PARENT_LOCATION_LEVEL_FK,
      llp.NAME              as PARENT_LOCATION_LEVEL_NAME
    from location_hierarchy lh
         join location lf
              join location_level llf
                on lf.location_level_fk = llf.id
           on lh.child_location_fk = lf.id
        join location lp
              join location_level llp
                on lp.location_level_fk = llp.id
           on lh.parent_location_fk = lp.id
    where lf.location_level_fk in (170,171,172,173,174,175,176,185,186,187,188,189)
  )
select 
  --
  h170.CHILD_LOCATION_LEVEL_FK     as ZONE_POLITIQUE_LOC_LEVEL_FK,
  h170.CHILD_LOCATION_LEVEL_NAME   as ZONE_POLITIQUE_LOC_LEVEL_NAME,
  h170.CHILD_LOCATION_FK           as ZONE_POLITIQUE_LOC_FK,
  h170.CHILD_LOCATION_LABEL        as ZONE_POLITIQUE_LOC_LABEL,
  h170.CHILD_LOCATION_NAME         as ZONE_POLITIQUE_LOC_NAME,
  h170.CHILD_LOCATION_VALIDITY_FK  as ZONE_POLITIQUE_VALIDITY_FK,
  h170.CHILD_LOCATION_STATUS_FK    as ZONE_POLITIQUE_STATUS_FK,
  --
  h171.CHILD_LOCATION_LEVEL_FK     as EAUX_NATIONALE_LOC_LEVEL_FK,
  h171.CHILD_LOCATION_LEVEL_NAME   as EAUX_NATIONALE_LOC_LEVEL_NAME,
  h171.CHILD_LOCATION_FK           as EAUX_NATIONALE_LOC_FK,
  h171.CHILD_LOCATION_LABEL        as EAUX_NATIONALE_LOC_LABEL,
  h171.CHILD_LOCATION_NAME         as EAUX_NATIONALE_LOC_NAME,
  h171.CHILD_LOCATION_VALIDITY_FK  as EAUX_NATIONALE_VALIDITY_FK,
  h171.CHILD_LOCATION_STATUS_FK    as EAUX_NATIONALE_STATUS_FK, 
  --
  h172.CHILD_LOCATION_LEVEL_FK     as DELIM_0_200_LOC_LEVEL_FK,
  h172.CHILD_LOCATION_LEVEL_NAME   as DELIM_0_200_LOC_LEVEL_NAME,
  h172.CHILD_LOCATION_FK           as DELIM_0_200_LOC_FK,
  h172.CHILD_LOCATION_LABEL        as DELIM_0_200_LOC_LABEL,
  h172.CHILD_LOCATION_NAME         as DELIM_0_200_LOC_NAME,
  h172.CHILD_LOCATION_VALIDITY_FK  as DELIM_0_200_VALIDITY_FK,
  h172.CHILD_LOCATION_STATUS_FK    as DELIM_0_200_STATUS_FK,
  --
  h173.CHILD_LOCATION_LEVEL_FK     as DELIM_0_12_LOC_LEVEL_FK,
  h173.CHILD_LOCATION_LEVEL_NAME   as DELIM_0_12_LOC_LEVEL_NAME,
  h173.CHILD_LOCATION_FK           as DELIM_0_12_LOC_FK,
  h173.CHILD_LOCATION_LABEL        as DELIM_0_12_LOC_LABEL,
  h173.CHILD_LOCATION_NAME         as DELIM_0_12_LOC_NAME,
  h173.CHILD_LOCATION_VALIDITY_FK  as DELIM_0_12_VALIDITY_FK,
  h173.CHILD_LOCATION_STATUS_FK    as DELIM_0_12_STATUS_FK,
  --
  h174.CHILD_LOCATION_LEVEL_FK     as DELIM_12_200_LOC_LEVEL_FK,
  h174.CHILD_LOCATION_LEVEL_NAME   as DELIM_12_200_LOC_LEVEL_NAME,
  h174.CHILD_LOCATION_FK           as DELIM_12_200_LOC_FK,
  h174.CHILD_LOCATION_LABEL        as DELIM_12_200_LOC_LABEL,
  h174.CHILD_LOCATION_NAME         as DELIM_12_200_LOC_NAME,
  h174.CHILD_LOCATION_VALIDITY_FK  as DELIM_12_200_VALIDITY_FK,
  h174.CHILD_LOCATION_STATUS_FK    as DELIM_12_200_STATUS_FK,
  --
  h175.CHILD_LOCATION_LEVEL_FK     as DELIM_12_24_LOC_LEVEL_FK,
  h175.CHILD_LOCATION_LEVEL_NAME   as DELIM_12_24_LOC_LEVEL_NAME,
  h175.CHILD_LOCATION_FK           as DELIM_12_24_LOC_FK,
  h175.CHILD_LOCATION_LABEL        as DELIM_12_24_LOC_LABEL,
  h175.CHILD_LOCATION_NAME         as DELIM_12_24_LOC_NAME,
  h175.CHILD_LOCATION_VALIDITY_FK  as DELIM_12_24_VALIDITY_FK,
  h175.CHILD_LOCATION_STATUS_FK    as DELIM_12_24_STATUS_FK,
  --
  h176.CHILD_LOCATION_LEVEL_FK     as DELIM_24_200_LOC_LEVEL_FK,
  h176.CHILD_LOCATION_LEVEL_NAME   as DELIM_24_200_LOC_LEVEL_NAME,
  h176.CHILD_LOCATION_FK           as DELIM_24_200_LOC_FK,
  h176.CHILD_LOCATION_LABEL        as DELIM_24_200_LOC_LABEL,
  h176.CHILD_LOCATION_NAME         as DELIM_24_200_LOC_NAME,
  h176.CHILD_LOCATION_VALIDITY_FK  as DELIM_24_200_VALIDITY_FK,
  h176.CHILD_LOCATION_STATUS_FK    as DELIM_24_200_STATUS_FK,
  --
  h185.CHILD_LOCATION_LEVEL_FK     as DELIM_0_3_LOC_LEVEL_FK,
  h185.CHILD_LOCATION_LEVEL_NAME   as DELIM_0_3_LOC_LEVEL_NAME,
  h185.CHILD_LOCATION_FK           as DELIM_0_3_LOC_FK,
  h185.CHILD_LOCATION_LABEL        as DELIM_0_3_LOC_LABEL,
  h185.CHILD_LOCATION_NAME         as DELIM_0_3_LOC_NAME,
  h185.CHILD_LOCATION_VALIDITY_FK  as DELIM_0_3_VALIDITY_FK,
  h185.CHILD_LOCATION_STATUS_FK    as DELIM_0_3_STATUS_FK,
  --
  h186.CHILD_LOCATION_LEVEL_FK     as DELIM_3_6_LOC_LEVEL_FK,
  h186.CHILD_LOCATION_LEVEL_NAME   as DELIM_3_6_LOC_LEVEL_NAME,
  h186.CHILD_LOCATION_FK           as DELIM_3_6_LOC_FK,
  h186.CHILD_LOCATION_LABEL        as DELIM_3_6_LOC_LABEL,
  h186.CHILD_LOCATION_NAME         as DELIM_3_6_LOC_NAME,
  h186.CHILD_LOCATION_VALIDITY_FK  as DELIM_3_6_VALIDITY_FK,
  h186.CHILD_LOCATION_STATUS_FK    as DELIM_3_6_STATUS_FK,
  --
  h187.CHILD_LOCATION_LEVEL_FK     as DELIM_6_12_LOC_LEVEL_FK,
  h187.CHILD_LOCATION_LEVEL_NAME   as DELIM_6_12_LOC_LEVEL_NAME,
  h187.CHILD_LOCATION_FK           as DELIM_6_12_LOC_FK,
  h187.CHILD_LOCATION_LABEL        as DELIM_6_12_LOC_LABEL,
  h187.CHILD_LOCATION_NAME         as DELIM_6_12_LOC_NAME,
  h187.CHILD_LOCATION_VALIDITY_FK  as DELIM_6_12_VALIDITY_FK,
  h187.CHILD_LOCATION_STATUS_FK    as DELIM_6_12_STATUS_FK,
  --
  h188.CHILD_LOCATION_LEVEL_FK     as DELIM_0_6_LOC_LEVEL_FK,
  h188.CHILD_LOCATION_LEVEL_NAME   as DELIM_0_6_LOC_LEVEL_NAME,
  h188.CHILD_LOCATION_FK           as DELIM_0_6_LOC_FK,
  h188.CHILD_LOCATION_LABEL        as DELIM_0_6_LOC_LABEL,
  h188.CHILD_LOCATION_NAME         as DELIM_0_6_LOC_NAME,
  h188.CHILD_LOCATION_VALIDITY_FK  as DELIM_0_6_VALIDITY_FK,
  h188.CHILD_LOCATION_STATUS_FK    as DELIM_0_6_STATUS_FK,
  --
  h189.CHILD_LOCATION_LEVEL_FK     as DELIM_3_12_LOC_LEVEL_FK,
  h189.CHILD_LOCATION_LEVEL_NAME   as DELIM_3_12_LOC_LEVEL_NAME,
  h189.CHILD_LOCATION_FK           as DELIM_3_12_LOC_FK,
  h189.CHILD_LOCATION_LABEL        as DELIM_3_12_LOC_LABEL,
  h189.CHILD_LOCATION_NAME         as DELIM_3_12_LOC_NAME,
  h189.CHILD_LOCATION_VALIDITY_FK  as DELIM_3_12_VALIDITY_FK,
  h189.CHILD_LOCATION_STATUS_FK    as DELIM_3_12_STATUS_FK
from hiearchy h170
     left join hiearchy h171
       on h170.CHILD_LOCATION_FK = h171.PARENT_LOCATION_FK
      and h171.CHILD_LOCATION_LEVEL_FK = 171
     left join hiearchy h172
       on h171.CHILD_LOCATION_FK = h172.PARENT_LOCATION_FK
      and h172.CHILD_LOCATION_LEVEL_FK = 172
     left join hiearchy h173
       on h172.CHILD_LOCATION_FK = h173.PARENT_LOCATION_FK
      and h173.CHILD_LOCATION_LEVEL_FK = 173
     left join hiearchy h174
       on h172.CHILD_LOCATION_FK = h174.PARENT_LOCATION_FK
      and h174.CHILD_LOCATION_LEVEL_FK = 174
     left join hiearchy h175
       on h172.CHILD_LOCATION_FK = h175.PARENT_LOCATION_FK
      and h175.CHILD_LOCATION_LEVEL_FK = 175
     left join hiearchy h176
       on h172.CHILD_LOCATION_FK = h176.PARENT_LOCATION_FK
      and h176.CHILD_LOCATION_LEVEL_FK = 176
     left join hiearchy h185
       on h172.CHILD_LOCATION_FK = h185.PARENT_LOCATION_FK
      and h185.CHILD_LOCATION_LEVEL_FK = 185
     left join hiearchy h186
       on h172.CHILD_LOCATION_FK = h186.PARENT_LOCATION_FK
      and h186.CHILD_LOCATION_LEVEL_FK = 186
     left join hiearchy h187
       on h172.CHILD_LOCATION_FK = h187.PARENT_LOCATION_FK
      and h187.CHILD_LOCATION_LEVEL_FK = 187
     left join hiearchy h188
       on h172.CHILD_LOCATION_FK = h188.PARENT_LOCATION_FK
      and h188.CHILD_LOCATION_LEVEL_FK = 188
     left join hiearchy h189
       on h172.CHILD_LOCATION_FK = h189.PARENT_LOCATION_FK
      and h189.CHILD_LOCATION_LEVEL_FK = 189
where h170.CHILD_LOCATION_LEVEL_FK = 170;


----------------------------------------------------------
-- 22/12/2014 EB Vue métier DENORMALIZED_LOC_STAT (mantis #121632)      
---------------------------------------------------------- 
CREATE OR REPLACE VIEW DENORMALIZED_LOC_STAT AS
with
  hiearchy as (
    select
      lf.id                 as CHILD_LOCATION_FK,
      lf.label              as CHILD_LOCATION_LABEL,
      lf.name               as CHILD_LOCATION_NAME,
      lf.status_fk          as CHILD_LOCATION_STATUS_FK,
      lf.validity_status_fk as CHILD_LOCATION_VALIDITY_FK,
      llf.id                as CHILD_LOCATION_LEVEL_FK,
      llf.NAME              as CHILD_LOCATION_LEVEL_NAME,
      lp.id                 as PARENT_LOCATION_FK,
      lp.label              as PARENT_LOCATION_LABEL,
      lp.name               as PARENT_LOCATION_NAME,
      lp.status_fk          as PARENT_LOCATION_STATUS_FK,
      lp.validity_status_fk as PARENT_LOCATION_VALIDITY_FK,
      llp.id                as PARENT_LOCATION_LEVEL_FK,
      llp.NAME              as PARENT_LOCATION_LEVEL_NAME
    from location_hierarchy lh
         join location lf
              join location_level llf
                on lf.location_level_fk = llf.id
           on lh.child_location_fk = lf.id
        join location lp
              join location_level llp
                on lp.location_level_fk = llp.id
           on lh.parent_location_fk = lp.id
    where lf.location_level_fk in (101,110,111,112,113,114,117)
  )
select 
  --
  h101.CHILD_LOCATION_LEVEL_FK     as FAO_ZONELOC_LEVEL_FK,
  h101.CHILD_LOCATION_LEVEL_NAME   as FAO_ZONELOC_LEVEL_NAME,
  h101.CHILD_LOCATION_FK           as FAO_ZONELOC_FK,
  h101.CHILD_LOCATION_LABEL        as FAO_ZONELOC_LABEL,
  h101.CHILD_LOCATION_NAME         as FAO_ZONELOC_NAME,
  h101.CHILD_LOCATION_VALIDITY_FK  as FAO_ZONEVALIDITY_FK,
  h101.CHILD_LOCATION_STATUS_FK    as FAO_ZONESTATUS_FK,
  --
  h110.CHILD_LOCATION_LEVEL_FK     as CIEM_SOUS_ZONE_LOC_LEVEL_FK,
  h110.CHILD_LOCATION_LEVEL_NAME   as CIEM_SOUS_ZONE_LOC_LEVEL_NAME,
  h110.CHILD_LOCATION_FK           as CIEM_SOUS_ZONE_LOC_FK,
  h110.CHILD_LOCATION_LABEL        as CIEM_SOUS_ZONE_LOC_LABEL,
  h110.CHILD_LOCATION_NAME         as CIEM_SOUS_ZONE_LOC_NAME,
  h110.CHILD_LOCATION_VALIDITY_FK  as CIEM_SOUS_ZONE_VALIDITY_FK,
  h110.CHILD_LOCATION_STATUS_FK    as CIEM_SOUS_ZONE_STATUS_FK, 
  --
  h111.CHILD_LOCATION_LEVEL_FK     as CIEM_DIVISION_LOC_LEVEL_FK,
  h111.CHILD_LOCATION_LEVEL_NAME   as CIEM_DIVISION_LOC_LEVEL_NAME,
  h111.CHILD_LOCATION_FK           as CIEM_DIVISION_LOC_FK,
  h111.CHILD_LOCATION_LABEL        as CIEM_DIVISION_LOC_LABEL,
  h111.CHILD_LOCATION_NAME         as CIEM_DIVISION_LOC_NAME,
  h111.CHILD_LOCATION_VALIDITY_FK  as CIEM_DIVISION_VALIDITY_FK,
  h111.CHILD_LOCATION_STATUS_FK    as CIEM_DIVISION_STATUS_FK,
  --
  h112.CHILD_LOCATION_LEVEL_FK     as CIEM_SOUS_DIV_LOC_LEVEL_FK,
  h112.CHILD_LOCATION_LEVEL_NAME   as CIEM_SOUS_DIV_LOC_LEVEL_NAME,
  h112.CHILD_LOCATION_FK           as CIEM_SOUS_DIV_LOC_FK,
  h112.CHILD_LOCATION_LABEL        as CIEM_SOUS_DIV_LOC_LABEL,
  h112.CHILD_LOCATION_NAME         as CIEM_SOUS_DIV_LOC_NAME,
  h112.CHILD_LOCATION_VALIDITY_FK  as CIEM_SOUS_DIV_VALIDITY_FK,
  h112.CHILD_LOCATION_STATUS_FK    as CIEM_SOUS_DIV_STATUS_FK,
  --
  h113.CHILD_LOCATION_LEVEL_FK     as STAT_RECTANGLE_LOC_LEVEL_FK,
  h113.CHILD_LOCATION_LEVEL_NAME   as STAT_RECTANGLE_LOC_LEVEL_NAME,
  h113.CHILD_LOCATION_FK           as STAT_RECTANGLE_LOC_FK,
  h113.CHILD_LOCATION_LABEL        as STAT_RECTANGLE_LOC_LABEL,
  h113.CHILD_LOCATION_NAME         as STAT_RECTANGLE_LOC_NAME,
  h113.CHILD_LOCATION_VALIDITY_FK  as STAT_RECTANGLE_VALIDITY_FK,
  h113.CHILD_LOCATION_STATUS_FK    as STAT_RECTANGLE_STATUS_FK,
  --
  h114.CHILD_LOCATION_LEVEL_FK     as STAT_SOUS_RECT_LOC_LEVEL_FK,
  h114.CHILD_LOCATION_LEVEL_NAME   as STAT_SOUS_RECT_LOC_LEVEL_NAME,
  h114.CHILD_LOCATION_FK           as STAT_SOUS_RECT_LOC_FK,
  h114.CHILD_LOCATION_LABEL        as STAT_SOUS_RECT_LOC_LABEL,
  h114.CHILD_LOCATION_NAME         as STAT_SOUS_RECT_LOC_NAME,
  h114.CHILD_LOCATION_VALIDITY_FK  as STAT_SOUS_RECT_VALIDITY_FK,
  h114.CHILD_LOCATION_STATUS_FK    as STAT_SOUS_RECT_STATUS_FK,
  --
  h117.CHILD_LOCATION_LEVEL_FK     as STAT_UNITE_LOC_LEVEL_FK,
  h117.CHILD_LOCATION_LEVEL_NAME   as STAT_UNITE_LOC_LEVEL_NAME,
  h117.CHILD_LOCATION_FK           as STAT_UNITE_LOC_FK,
  h117.CHILD_LOCATION_LABEL        as STAT_UNITE_LOC_LABEL,
  h117.CHILD_LOCATION_NAME         as STAT_UNITE_LOC_NAME,
  h117.CHILD_LOCATION_VALIDITY_FK  as STAT_UNITE_VALIDITY_FK,
  h117.CHILD_LOCATION_STATUS_FK    as STAT_UNITE_STATUS_FK
from hiearchy h101
     left join hiearchy h110
       on h101.CHILD_LOCATION_FK = h110.PARENT_LOCATION_FK
      and h110.CHILD_LOCATION_LEVEL_FK = 110
     left join hiearchy h111
       on h110.CHILD_LOCATION_FK = h111.PARENT_LOCATION_FK
      and h111.CHILD_LOCATION_LEVEL_FK = 111
     left join hiearchy h112
       on h111.CHILD_LOCATION_FK = h112.PARENT_LOCATION_FK
      and h112.CHILD_LOCATION_LEVEL_FK = 112
     left join hiearchy h113
       on h112.CHILD_LOCATION_FK = h113.PARENT_LOCATION_FK
      and h113.CHILD_LOCATION_LEVEL_FK = 113
     left join hiearchy h114
       on h113.CHILD_LOCATION_FK = h114.PARENT_LOCATION_FK
      and h114.CHILD_LOCATION_LEVEL_FK = 114
     left join hiearchy h117
       on h114.CHILD_LOCATION_FK = h117.PARENT_LOCATION_FK
      and h117.CHILD_LOCATION_LEVEL_FK = 117
where h101.CHILD_LOCATION_LEVEL_FK = 101;


----------------------------------------------------------
-- 08/01/2015 EB Vue métier DENORMALIZED_GEAR_FAO (mantis #20855)      
---------------------------------------------------------- 
CREATE OR REPLACE FORCE VIEW DENORMALIZED_GEAR_FAO AS 
SELECT
  /* CATEGORY GROUPING */
  GI.GROUPING_FK,
  GRP.LABEL CATEGORY_CODE,
  GRP.NAME CATEGORY_NAME_FR,
  TI_GRP_EN.EXTERNAL_CODE CATEGORY_NAME_EN,
  TI_GRP_ISS.EXTERNAL_CODE CATEGORY_ISSCFG,
  /* GEAR */
  G.LABEL CODE_3A,
  TI_ISS.EXTERNAL_CODE ISSCFG,
  G.NAME FRENCH_NAME,
  TI_EN.EXTERNAL_CODE ENGLISH_NAME,
  G.DESCRIPTION DESCRIPTION,
  G.IS_FISHING_GEAR FISHING_GEAR,
  G.IS_ACTIVE ACTIVE_GEAR,
  G.IS_TOWED TOWED_GEAR,
  G.VALIDITY_STATUS_FK VALIDITY,
  G.STATUS_FK STATUS_FK
FROM GEAR G
     -- traduction anglaise
     LEFT JOIN TRANSCRIBING_ITEM TI_EN
            JOIN TRANSCRIBING_ITEM_TYPE TIT_EN
              ON TIT_EN.ID=TI_EN.TRANSCRIBING_ITEM_TYPE_FK
             AND TIT_EN.LABEL='LOCALE-EN.GEAR'
       ON G.ID=TI_EN.OBJECT_ID
     -- Traduction ISSCFG
     LEFT JOIN TRANSCRIBING_ITEM TI_ISS
            JOIN TRANSCRIBING_ITEM_TYPE TIT_ISS
              ON TIT_ISS.ID=TI_ISS.TRANSCRIBING_ITEM_TYPE_FK
             AND TIT_ISS.LABEL='FAO-GEAR.CSITEP'
       ON G.ID=TI_ISS.OBJECT_ID
    -- Regroupement 
    LEFT JOIN GROUPING_ITEM GI
            JOIN GROUPING GRP
                 JOIN GROUPING_LEVEL GL
                      JOIN GROUPING_CLASSIFICATION GC
                        ON GL.GROUPING_CLASSIFICATION_FK = GC.ID
                       AND GC.LABEL='GEAR_CAT'
                   ON GRP.GROUPING_LEVEL_FK = GL.ID
                  AND GL.LABEL='GEAR_CAT_FAO' 
              ON GI.GROUPING_FK = GRP.ID 
            -- Traduction anglaise du regroupement
            LEFT JOIN TRANSCRIBING_ITEM TI_GRP_EN
                 JOIN TRANSCRIBING_ITEM_TYPE TIT_GRP_EN 
                   ON TI_GRP_EN.TRANSCRIBING_ITEM_TYPE_FK=TIT_GRP_EN.ID
                  AND TIT_GRP_EN.LABEL='LOCALE-EN.GEAR'
              ON GI.GROUPING_FK=TI_GRP_EN.OBJECT_ID
            -- Traduction ISSCFG du groupe
            LEFT JOIN TRANSCRIBING_ITEM TI_GRP_ISS
                 JOIN TRANSCRIBING_ITEM_TYPE TIT_GRP_ISS 
                   ON TI_GRP_ISS.TRANSCRIBING_ITEM_TYPE_FK=TIT_GRP_ISS.ID
                  AND TIT_GRP_ISS.LABEL='FAO-GEAR.CSITEP'
              ON GI.GROUPING_FK=TI_GRP_ISS.OBJECT_ID  
       ON G.ID = GI.OBJECT_ID 
where G.GEAR_CLASSIFICATION_FK = 1;


----------------------------------------------------------
-- 26/01/2015 BL Add missing view AGE_READER_QUALIFICATIONS2PEOP (mantis #23785)
--               (was already existing in liquibase patch)      
---------------------------------------------------------- 
CREATE OR REPLACE FORCE VIEW AGE_READER_QUALIFICATIONS2PEOP AS 
SELECT
  AGE_READER_QUALIFICATION_FK as AGE_READER_QUALIFICATIONS_FK,
  PERSON_FK as PEOPLE_FK
FROM 
  AGE_READER_QUAL2PERSON;
  
  
----------------------------------------------------------
-- 26/01/2015 BL Add view DENORMALIZED_PROGRAM2PERSON
-- 23/03/2016 EM Added EMAIL in view DENORMALIZED_PROGRAM2PERSON (Mantis 29616)
---------------------------------------------------------- 
create or replace view DENORMALIZED_PROGRAM2PERSON as
select 
  pr.code                  as PROGRAM_FK,
  pr.description           as PROGRAM_DESCRIPTION,
  pe.ID                    as PERSON_FK,
  pe.LASTNAME              as PERSON_LASTNAME,
  pe.FIRSTNAME             as PERSON_FIRSTNAME,
  pe.USERNAME              as PERSON_USERNAME,
  pe.USERNAME_EXTRANET     as PERSON_USERNAME_EXTRANET,
  pe.EMAIL                 as PERSON_EMAIL,
  pe.STATUS_FK             as PERSON_STATUS_FK,
  pe.update_date           as PERSON_UPDATE_DATE,
  d.ID                     as DEPARTMENT_FK,
  d.CODE                   as DEPARTMENT_CODE,
  d.NAME                   as DEPARTMENT_NAME,
  d.STATUS_FK              as DEPARTMENT_STATUS_FK,
  p2p.UPDATE_DATE          as PROGRAM2PERSON_UPDATE_DATE,
  pp.id                    as PROGRAM_PRIVILGE_FK,
  pp.label                 as PROGRAM_PRIVILGE_LABEL,
  l.id                     as LOCATION_FK,
  l.label                  as LOCATION_LABEL,
  l.name                   as LOCATION_NAME,
  l.update_date            as LOCATION_UPDATE_DATE,
  l.status_fk              as LOCATION_STATUS_FK,
  refpe.ID                 as REF_PERSON_FK,
  refpe.LASTNAME           as REF_PERSON_LASTNAME,
  refpe.FIRSTNAME          as REF_PERSON_FIRSTNAME,
  refpe.USERNAME           as REF_PERSON_USERNAME,
  refpe.USERNAME_EXTRANET  as REF_PERSON_USERNAME_EXTRANET,
  refpe.STATUS_FK          as REF_PERSON_STATUS_FK,
  refpe.update_date        as REF_PERSON_UPDATE_DATE,
  refd.ID                  as REF_DEPARTMENT_FK,
  refd.CODE                as REF_DEPARTMENT_CODE,
  refd.NAME                as REF_DEPARTMENT_NAME,
  refd.STATUS_FK           as REF_DEPARTMENT_STATUS_FK
from program2person p2p
     join person pe
          join department d
            on pe.department_fk = d.id
       on p2p.person_fk = pe.id
     join program pr
       on p2p.program_fk = pr.code
     left join location l
       on p2p.location_fk = l.id
     left join person refpe
          join department refd
            on refpe.department_fk = refd.id
       on p2p.reference_person_fk = refpe.id
     join program_privilege pp
       on p2p.program_privilege_fk = pp.id
order by PROGRAM_FK, PERSON_FK, PROGRAM_PRIVILGE_FK, LOCATION_FK;


--------------------------------------------------------------------------------
-- Vue         : DENORMALIZED_OBSDEB_SYNC_OBS
-- Description : Dates de dernière synchronisation obsdeb par saisisseur
-- 08/07/2015  NR Creation
--------------------------------------------------------------------------------
create or replace view DENORMALIZED_OBSDEB_SYNC_OBS as
  select P.EMPLOYEE_NUMBER, P.LASTNAME, P.FIRSTNAME, P.STATUS_FK, max(OL.UPDATE_DATE) as DATE_MODIFICATION
  from OBSERVED_LOCATION OL
    inner join PERSON P on P.ID = OL.RECORDER_PERSON_FK
  where OL.PROGRAM_FK in ('SIH-OBSDEB', 'SIH-TELDEB', 'SIH-OPRDEB')
  group by P.EMPLOYEE_NUMBER, P.LASTNAME, P.FIRSTNAME, P.STATUS_FK
  order by max(OL.UPDATE_DATE)
;


--------------------------------------------------------------------------------
-- Vue         : DENORMALIZED_PSION_TAXON
-- Description : Vue métier sur les transcodages ARPEGE-TAXON.CODE pour Psion
-- 22/11/2017  NR Creation
--------------------------------------------------------------------------------
create or replace view DENORMALIZED_PSION_TAXON as
select
  TI.OBJECT_ID,
  TG.LABEL as OBJECT_LABEL,
  TI.EXTERNAL_CODE,
  regexp_substr(TI.EXTERNAL_CODE, '[^#]+', 1, 1) as CODE_ARPEGE,
  regexp_substr(TI.EXTERNAL_CODE, '[^#]+', 1, 2) as CODE_REFTAX,
  TN.REFERENCE_TAXON_FK as REFERENCE_TAXON_ID,
  TN.NAME as TAXON_NAME
from
  TRANSCRIBING_ITEM TI
  left outer join TAXON_GROUP TG
    on TG.ID = TI.OBJECT_ID
    and TG.TAXON_GROUP_TYPE_FK = 2
  left outer join TAXON_NAME TN
    on TN.REFERENCE_TAXON_FK = regexp_substr(TI.EXTERNAL_CODE, '[^#]+', 1, 3)
    and TN.IS_REFERENT = 1
where
  TRANSCRIBING_ITEM_TYPE_FK = (
    select ID from TRANSCRIBING_ITEM_TYPE where LABEL = 'ARPEGE-TAXON.CODE'
  )
;

--------------------------------------------------------------------------------
-- Vue         : DENORMALIZED_PSION_TAXON2PMFM
-- Description : Vue métier sur les transcodages ARPEGE-TAXON2PMFM.CODE pour Psion
-- 22/11/2017  NR Creation
--------------------------------------------------------------------------------
create or replace view DENORMALIZED_PSION_TAXON2PMFM as
select
  TI.OBJECT_ID,
  TG.LABEL as OBJECT_LABEL,
  TI.EXTERNAL_CODE,
  QV_DRES.ID as DRESSING_ID,
  QV_DRES.NAME as DRESSING_NAME,
  PMFM.ID as PMFM_ID,
  PMFM.PARAMETER_FK as PARAMETER_CODE,
  P.NAME as PARAMETER_NAME,
  U.SYMBOL as UNIT,
  PMFM.PRECISION as PRECISION
from
  TRANSCRIBING_ITEM TI
  left outer join TAXON_GROUP TG
    on TG.ID = TI.OBJECT_ID
    and TG.TAXON_GROUP_TYPE_FK = 2
  left outer join QUALITATIVE_VALUE QV_DRES
    on QV_DRES.ID = regexp_substr(TI.EXTERNAL_CODE, '[^#]+', 1, 1)
  left outer join PMFM
      inner join PARAMETER P
        on P.CODE = PMFM.PARAMETER_FK
      inner join UNIT U
        on U.ID = PMFM.UNIT_FK
    on PMFM.ID = regexp_substr(TI.EXTERNAL_CODE, '[^#]+', 1, 2)
where
  TRANSCRIBING_ITEM_TYPE_FK = (
    select ID from TRANSCRIBING_ITEM_TYPE where LABEL = 'ARPEGE-TAXON2PMFM.CODE'
  )
;

--------------------------------------------------------------------------------
-- Vue         : DENORMALIZED_PSION_CATUE
-- Description : Vue métier sur les transcodages ARPEGE-CATUE.CODE pour Psion
-- 22/11/2017  NR Creation
--------------------------------------------------------------------------------
create or replace view DENORMALIZED_PSION_CATUE as
select
  TI.OBJECT_ID,
  QV_CATUE.NAME as OBJECT_NAME,
  TI.EXTERNAL_CODE,
  L.ID as LOCATION_ID,
  L.LABEL as LOCATION_LABEL,
  L.LOCATION_LEVEL_FK as LOCATION_LEVEL_ID,
  TG.ID as TAXON_GROUP_ID,
  TG.LABEL as TAXON_GROUP_LABEL,
  QV_PRES.ID as PRESERVATION_ID,
  QV_PRES.NAME as PRESERVATION_NAME,
  QV_DRES.ID as DRESSING_ID,
  QV_DRES.NAME as DRESSING_NAME,
  QV_CATTER.ID as CAT_TERRAIN_ID,
  QV_CATTER.NAME as CAT_TERRAIN_NAME,
  regexp_substr(TI.EXTERNAL_CODE, '[^#]+', 1, 6) as DATE_DEBUT,
  regexp_substr(TI.EXTERNAL_CODE, '[^#]+', 1, 7) as DATE_FIN
from
  TRANSCRIBING_ITEM TI
  left outer join QUALITATIVE_VALUE QV_CATUE
    on QV_CATUE.ID = TI.OBJECT_ID
  left outer join LOCATION L
    on L.ID = regexp_substr(TI.EXTERNAL_CODE, '[^#]+', 1, 1)
  left outer join TAXON_GROUP TG
    on TG.ID = regexp_substr(TI.EXTERNAL_CODE, '[^#]+', 1, 2)
    and TG.TAXON_GROUP_TYPE_FK = 2
  left outer join QUALITATIVE_VALUE QV_PRES
    on QV_PRES.ID = regexp_substr(TI.EXTERNAL_CODE, '[^#]+', 1, 3)
  left outer join QUALITATIVE_VALUE QV_DRES
    on QV_DRES.ID = regexp_substr(TI.EXTERNAL_CODE, '[^#]+', 1, 4)
  left outer join QUALITATIVE_VALUE QV_CATTER
    on QV_CATTER.ID = regexp_substr(TI.EXTERNAL_CODE, '[^#]+', 1, 5)
where
  TRANSCRIBING_ITEM_TYPE_FK = (
    select ID from TRANSCRIBING_ITEM_TYPE where LABEL = 'ARPEGE-CATUE.CODE'
  )
;